@@ -29,6 +29,7 @@
 #include "ui-transaction.h"
 #include "gtk-dateentry.h"
 
+#include "ui-account.h"
 #include "ui-payee.h"
 #include "ui-category.h"
 
@@ -68,11 +69,56 @@ static void register_panel_make_archive(GtkWidget *widget, gpointer user_data);
 
 static void status_selected_foreach_func (GtkTreeModel	*model, GtkTreePath	 *path, GtkTreeIter	 *iter, gpointer userdata);
 
+static void ui_multipleedit_dialog_prefill( GtkWidget *widget, Transaction *ope, gint column_id );
+static void register_panel_edit_multiple(GtkWidget *widget, Transaction *txn, gint column_id, gpointer user_data);
+
 static void register_panel_selection(GtkTreeSelection *treeselection, gpointer user_data);
 static void register_panel_onRowActivated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer userdata);
 
 
 
+static void ui_multipleedit_dialog_prefill( GtkWidget *widget, Transaction *ope, gint column_id )
+{
+struct ui_multipleedit_dialog_data *data;
+gchar *tagstr;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print ("\n[ui-multipleedit] prefill\n") );
+
+	if(ope != NULL)
+	//if(col_id >= LST_DSPOPE_DATE && col_id != LST_DSPOPE_BALANCE)
+	{
+		switch( column_id )
+		{
+			case LST_DSPOPE_INFO:
+				gtk_combo_box_set_active(GTK_COMBO_BOX(data->NU_mode), ope->paymode);
+				gtk_entry_set_text(GTK_ENTRY(data->ST_info), (ope->info != NULL) ? ope->info : "");
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(data->CM_mode), TRUE);
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(data->CM_info), TRUE);
+				break;
+			case LST_DSPOPE_PAYEE:
+				ui_pay_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_pay), ope->kpay);
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(data->CM_pay), TRUE);
+				break;
+			case LST_DSPOPE_WORDING:
+				gtk_entry_set_text(GTK_ENTRY(data->ST_memo), (ope->wording != NULL) ? ope->wording : "");
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(data->CM_memo), TRUE);
+				break;
+			case LST_DSPOPE_CATEGORY:
+				ui_cat_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_cat), ope->kcat);
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(data->CM_cat), TRUE);
+				break;
+			case LST_DSPOPE_TAGS:
+				tagstr = transaction_tags_tostring(ope);
+				gtk_entry_set_text(GTK_ENTRY(data->ST_tags), (tagstr != NULL) ? tagstr : "");
+				g_free(tagstr);
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(data->CM_tags), TRUE);
+				break;
+		}
+	}
+}
+
 
 static void ui_multipleedit_dialog_update( GtkWidget *widget, gpointer user_data )
 {
@@ -88,6 +134,9 @@ struct ui_multipleedit_dialog_data *data;
 		gtk_widget_set_sensitive (data->ST_info, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_info)) );
 	}
 
+	if(data->PO_acc)
+		gtk_widget_set_sensitive (data->PO_acc , gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_acc )) );
+
 	if(data->PO_pay)
 		gtk_widget_set_sensitive (data->PO_pay , gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_pay )) );
 
@@ -164,59 +213,103 @@ GList *selection, *list;
 
 		DB( g_print(" modifying %s %.2f\n", txn->wording, txn->amount) );
 
-		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_mode)) )
+		if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_INFO) == TRUE )
 		{
-			txn->paymode = gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
-			change = TRUE;
+			if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_mode)) )
+			{
+				txn->paymode = gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
+				change = TRUE;
+			}
+		
+			if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_info)) )
+			{
+				if(txn->info)
+				{
+					g_free(txn->info);
+					txn->info = NULL;
+					change = TRUE;
+				}
+
+				txt = gtk_entry_get_text(GTK_ENTRY(data->ST_info));
+				if (txt && *txt)
+				{
+					txn->info = g_strdup(txt);
+					change = TRUE;
+				}
+			}
+		}
+
+		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_acc)) )
+		{
+		guint32 nkacc = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_acc));
+
+			account_balances_sub(txn);
+			if( transaction_acc_move(txn, txn->kacc, nkacc) )
+			{
+			GtkTreeIter iter;
+
+				account_balances_add(txn);
+				DB( g_print(" -> acc: '%d'\n", nkacc) );	
+				gtk_tree_model_get_iter(model, &iter, list->data);
+				gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+				change = TRUE;
+			}
+		}
+
+		if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_PAYEE) == TRUE )
+		{
+			if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_pay)) )
+			{
+				txn->kpay = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_pay));
+				DB( g_print(" -> payee: '%d'\n", txn->kpay) );
+				change = TRUE;
+			}
+		}
+
+		if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_CATEGORY) == TRUE )
+		{
+			if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_cat)) )
+			{
+				if(!(txn->flags & OF_SPLIT))
+				{
+					txn->kcat = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_cat));
+					DB( g_print(" -> category: '%d'\n", txn->kcat) );
+					change = TRUE;
+				}
+			}
 		}
 		
-		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_info)) )
+		if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_TAGS) == TRUE )
 		{
-			txt = gtk_entry_get_text(GTK_ENTRY(data->ST_info));
-			if (txt && *txt)
+			if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_tags)) )
 			{
-				g_free(txn->info);
-				txn->info = g_strdup(txt);
-				change = TRUE;
+				txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_tags));
+				if (txt && *txt)
+				{
+					transaction_tags_parse(txn, txt);
+					DB( g_print(" -> tags: '%s'\n", txt) );
+					change = TRUE;
+				}
 			}
 		}
 
-		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_pay)) )
+		if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_WORDING) == TRUE )
 		{
-			txn->kpay = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_pay));
-			DB( g_print(" -> payee: '%d'\n", txn->kpay) );
-			change = TRUE;
-		}
-
-		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_cat)) )
-		{
-			if(!(txn->flags & OF_SPLIT))
+			if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_memo)) )
 			{
-				txn->kcat = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_cat));
-				DB( g_print(" -> category: '%d'\n", txn->kcat) );
-				change = TRUE;
-			}
-		}
+				if(txn->wording)
+				{
+					g_free(txn->wording);
+					txn->wording = NULL;	
+					change = TRUE;
+				}
 
-		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_tags)) )
-		{
-			txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_tags));
-			if (txt && *txt)
-			{
-				transaction_tags_parse(txn, txt);
-				DB( g_print(" -> tags: '%s'\n", txt) );
-				change = TRUE;
-			}
-		}
-
-		if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_memo)) )
-		{
-			txt = gtk_entry_get_text(GTK_ENTRY(data->ST_memo));
-			if (txt && *txt)
-			{
-				g_free(txn->wording);
-				txn->wording = g_strdup(txt);
-				change = TRUE;
+				txt = gtk_entry_get_text(GTK_ENTRY(data->ST_memo));
+				if (txt && *txt)
+				{
+					txn->wording = g_strdup(txt);
+					change = TRUE;
+				}
 			}
 		}
 
@@ -350,7 +443,21 @@ gint row;
 
 		g_signal_connect (data->CM_info , "toggled", G_CALLBACK (ui_multipleedit_dialog_update), NULL);
 	}
+
+	row++;
+	label = make_label_widget(_("A_ccount:"));
+	data->LB_acc = label;
+	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+	widget = gtk_check_button_new();
+	data->CM_acc = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+	widget = ui_acc_comboboxentry_new(label);
+	data->PO_acc = widget;
+	gtk_widget_set_hexpand (widget, TRUE);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 	
+	g_signal_connect (data->CM_acc , "toggled", G_CALLBACK (ui_multipleedit_dialog_update), NULL);
+
 	if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_PAYEE) == TRUE )
 	{
 		row++;
@@ -418,11 +525,18 @@ gint row;
 
 	ui_multipleedit_dialog_update(dialog, NULL);
 
+	ui_acc_comboboxentry_populate(GTK_COMBO_BOX(data->PO_acc), GLOBALS->h_acc, ACC_LST_INSERT_NORMAL);
 	ui_pay_comboboxentry_populate(GTK_COMBO_BOX(data->PO_pay), GLOBALS->h_pay);
 	ui_cat_comboboxentry_populate(GTK_COMBO_BOX(data->PO_cat), GLOBALS->h_cat);
 
 	gtk_widget_show_all (dialog);
 
+	if(data->has_xfer == TRUE)
+	{
+		hb_widget_visible (data->LB_acc, FALSE);
+		hb_widget_visible (data->CM_acc, FALSE);
+		hb_widget_visible (data->PO_acc, FALSE);
+	}
 
 	if( list_txn_column_id_isvisible(GTK_TREE_VIEW(data->treeview), LST_DSPOPE_INFO) == TRUE )
 	{
@@ -476,19 +590,8 @@ struct register_panel_data *data = user_data;
 static void register_panel_action_multiedit(GtkAction *action, gpointer user_data)
 {
 struct register_panel_data *data = user_data;
-GtkWidget *dialog;
 
-	dialog = ui_multipleedit_dialog_new(GTK_WINDOW(data->window), GTK_TREE_VIEW(data->LV_ope));
-
-	//wait for the user
-	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
-
-	if( result == GTK_RESPONSE_ACCEPT )
-	{
-		ui_multipleedit_dialog_apply (dialog, NULL);
-	}
-
-	gtk_widget_destroy (dialog);
+	register_panel_edit_multiple(data->window, NULL, 0, user_data);
 }
 
 static void register_panel_action_reconcile(GtkAction *action, gpointer user_data)
@@ -592,8 +695,8 @@ gint count;
 	{
 		ui_dialog_msg_infoerror(GTK_WINDOW(data->window), GTK_MESSAGE_INFO,
 		_("Check internal transfert result"),
-		_("No inconsistency found !"),
-		NULL);
+		_("No inconsistency found !")
+		);
 	}
 	else
 	{
@@ -624,7 +727,7 @@ gint count;
 				//-display the src txn
 				//-enable to display 1 of xxx if more than 1
 
-				transaction_xfer_search_or_add_child(GTK_WINDOW(data->window), stxn);
+				transaction_xfer_search_or_add_child(GTK_WINDOW(data->window), stxn, TRUE);
 
 				tmplist = g_list_next(tmplist);
 			}	
@@ -663,7 +766,7 @@ gint result;
 
 	result = ui_dialog_msg_confirm_alert(
 			GTK_WINDOW(data->window),
-			_("Are you sure you want to convert this account\nto Major euro currency?"),
+			_("Are you sure you want to convert this account\nto Euro as Major currency?"),
 			msg,
 			_("_Convert")
 		);
@@ -684,7 +787,7 @@ struct register_panel_data *data = user_data;
 gint count;
 gboolean usermode = TRUE;
 
-	count = transaction_auto_assign(GLOBALS->ope_list, data->accnum);
+	count = transaction_auto_assign(g_queue_peek_head_link(data->acc->txn_queue), data->accnum);
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_ope));
 	GLOBALS->changes_count += count;
 
@@ -696,10 +799,10 @@ gboolean usermode = TRUE;
 		if(count == 0)
 			txt = _("No transaction changed");
 		else
-			txt = _("transaction auto assigned: %d");
+			txt = _("transaction changed: %d");
 
 		ui_dialog_msg_infoerror(GTK_WINDOW(data->window), GTK_MESSAGE_INFO,
-			_("Auto assignment result"),
+			_("Automatic assignment result"),
 			txt,
 			count);
 	}
@@ -822,6 +925,40 @@ GIOChannel *io;
 
 
 
+
+
+static void register_panel_edit_multiple(GtkWidget *widget, Transaction *txn, gint column_id, gpointer user_data)
+{
+struct register_panel_data *data;
+GtkWidget *dialog;
+
+	DB( g_print("\n[account] edit multiple\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print(" - txn:%p, column: %d\n", txn, column_id) );
+
+	dialog = ui_multipleedit_dialog_new(GTK_WINDOW(data->window), GTK_TREE_VIEW(data->LV_ope));
+
+	if(txn != NULL && column_id != 0)
+	{
+		ui_multipleedit_dialog_prefill(dialog, txn, column_id);
+	}
+
+	//wait for the user
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if( result == GTK_RESPONSE_ACCEPT )
+	{
+		ui_multipleedit_dialog_apply (dialog, NULL);
+	}
+
+	gtk_widget_destroy (dialog);
+	
+	register_panel_update(data->LV_ope, GINT_TO_POINTER(UF_BALANCE));
+}
+
+
 /*
 ** make an archive with the active transaction
 */
@@ -1014,24 +1151,21 @@ gushort lpos = 1;
 	if(data->do_sort)
 	{
 		DB( g_print(" - complete txn sort\n") );
-		GLOBALS->ope_list = da_transaction_sort(GLOBALS->ope_list);
+		
+		da_transaction_queue_sort(data->acc->txn_queue);
 		data->do_sort = FALSE;
 	}
 
-	list = g_list_first(GLOBALS->ope_list);
+	list = g_queue_peek_head_link(data->acc->txn_queue);
 	while (list != NULL)
 	{
-	Transaction *ope;
+	Transaction *ope = list->data;
 
-		ope = list->data;
-		if(ope->kacc == data->accnum)
-		{	
-			//#1267344
-			if(!(ope->status == TXN_STATUS_REMIND))
+		//#1267344
+		if(!(ope->status == TXN_STATUS_REMIND))
 				balance += ope->amount;
 
-			ope->balance = balance;
-		}
+		ope->balance = balance;
 
 		if(ope->date == ldate)
 		{
@@ -1066,7 +1200,7 @@ GList *list;
 		g_ptr_array_free (data->gpatxn, TRUE);
 
 #if MYDEBUG == 1
-	guint nbtxn = g_list_length (GLOBALS->ope_list);
+	guint nbtxn = g_queue_get_length (data->acc->txn_queue);
 	g_print(" - nb txn %d\n", nbtxn);
 #endif
 	
@@ -1074,22 +1208,19 @@ GList *list;
 
 	//data->hidden = 0;
 
-	list = g_list_first(GLOBALS->ope_list); i=0;
+	list = g_queue_peek_head_link(data->acc->txn_queue); i=0;
 	while (list != NULL)
 	{
 	Transaction *ope = list->data;
 
-		if(ope->kacc == data->accnum)
+		if(filter_test(data->filter, ope) == 1)
 		{
-			if(filter_test(data->filter, ope) == 1)
-			{
-				g_ptr_array_add(data->gpatxn, (gpointer)ope);
-			}
-			/*else
-			{
-				data->hidden++;
-			}*/
+			g_ptr_array_add(data->gpatxn, (gpointer)ope);
 		}
+		/*else
+		{
+			data->hidden++;
+		}*/
 
 #if MYDEBUG == 1
 		
@@ -1417,7 +1548,6 @@ gboolean result;
 					{
 						delete_active_transaction(GTK_TREE_VIEW(data->LV_ope));
 					}
-
 					
 					//da_transaction_copy(new_txn, old_txn);
 
@@ -1427,11 +1557,8 @@ gboolean result;
 					GLOBALS->changes_count++;
 				}
 
-
 				da_transaction_free (old_txn);
-			
 			}
-
 		}
 		break;
 
@@ -1505,7 +1632,7 @@ gboolean result;
 
 					gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
 					
-					GLOBALS->ope_list = g_list_remove(GLOBALS->ope_list, entry);
+					g_queue_remove(data->acc->txn_queue, entry);
 					//#1419304 we keep the deleted txn to a trash stack	
 					//da_transaction_free(entry);
 					g_trash_stack_push(&GLOBALS->txn_stk, entry);
@@ -1696,7 +1823,6 @@ gint count = 0;
 
 	GLOBALS->minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
 
-
 	/* set window title */
 	if(flags & UF_TITLE)
 	{
@@ -1786,9 +1912,9 @@ gint count = 0;
 
 		register_panel_balance_refresh(widget);
 		
-		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[0]), data->acc->bal_bank, GLOBALS->minor);
-		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[1]), data->acc->bal_today, GLOBALS->minor);
-		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[2]), data->acc->bal_future, GLOBALS->minor);
+		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[0]), data->acc->bal_bank, data->acc->kcur, GLOBALS->minor);
+		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[1]), data->acc->bal_today, data->acc->kcur, GLOBALS->minor);
+		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[2]), data->acc->bal_future, data->acc->kcur, GLOBALS->minor);
 
 		ui_mainwindow_populate_accounts(GLOBALS->mainwindow, NULL);
 	}
@@ -1838,9 +1964,9 @@ gint count = 0;
 
 		DB( g_print(" %f - %f = %f\n", opeinc, opeexp, opeinc + opeexp) );
 
-		mystrfmon(buf1, 64-1, opeinc, GLOBALS->minor);
-		mystrfmon(buf2, 64-1, -opeexp, GLOBALS->minor);
-		mystrfmon(buf3, 64-1, opeinc + opeexp, GLOBALS->minor);
+		hb_strfmon(buf1, 64-1, opeinc, data->acc->kcur, GLOBALS->minor);
+		hb_strfmon(buf2, 64-1, -opeexp, data->acc->kcur, GLOBALS->minor);
+		hb_strfmon(buf3, 64-1, opeinc + opeexp, data->acc->kcur, GLOBALS->minor);
 	}
 
 	gchar *msg;
@@ -1848,7 +1974,7 @@ gint count = 0;
 	if( count <= 0 )
 	{
 		//msg = g_strdup_printf (_("transaction selected: %d, hidden: %d"), count, data->hidden);
-		mystrfmon(buf3, 64-1, data->totalsum, GLOBALS->minor);
+		hb_strfmon(buf3, 64-1, data->totalsum, data->acc->kcur, GLOBALS->minor);
 		msg = g_strdup_printf(_("%d items (%s)"), data->total, buf3);
 	}
 	else
@@ -1890,15 +2016,15 @@ Transaction *ope;
 		register_panel_action(GTK_WIDGET(treeview), GINT_TO_POINTER(ACTION_ACCOUNT_EDIT));
 	}
 	else
-	if(col_id >= LST_DSPOPE_DATE && col_id != LST_DSPOPE_BALANCE)
 	{
-		register_panel_action_multiedit(NULL, data);
+		if(col_id >= LST_DSPOPE_DATE && col_id != LST_DSPOPE_BALANCE)
+		{
+			register_panel_edit_multiple (data->window, ope, col_id, data);
+		}
 	}
 }
 
 
-
-
 /*
 static gint listview_context_cb (GtkWidget *widget, GdkEventButton *event, GtkWidget *menu)
 {
@@ -1937,11 +2063,14 @@ static gint listview_context_cb (GtkWidget *widget, GdkEventButton *event, GtkWi
 */
 void register_panel_window_init(GtkWidget *widget, gpointer user_data)
 {
+struct register_panel_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	DB( g_print("\n[account] init window\n") );
 
 	DB( g_print(" - sort transactions\n") );
-	GLOBALS->ope_list = da_transaction_sort(GLOBALS->ope_list);
+	da_transaction_queue_sort(data->acc->txn_queue);
 
 	//DB( g_print(" mindate=%d, maxdate=%d %x\n", data->filter->mindate,data->filter->maxdate) );
 
@@ -2031,93 +2160,43 @@ struct register_panel_data *data;
 }
 
 
-static void 
-quick_search_activate_cb (GtkEntry  *entry, gpointer  user_data)
+static void quick_search_text_changed_cb (GtkWidget *widget, gpointer user_data)
 {
 struct register_panel_data *data = user_data;
 
-	DB( g_print("quick search activate !\n") );
-
-	
-	register_panel_listview_populate (data->LV_ope);
-}
-
-
-static gint quick_search_text_changed_timeout (gpointer user_data)
-{
-struct register_panel_data *data = user_data;
-	
-	DB( g_print("quick search timed out !\n") );
-
 	register_panel_listview_populate (data->window);
-
-	data->timer_tag = 0;
-
-	return FALSE;
-}
-
-static void
-quick_search_text_changed_cb (GtkEntry   *entry,
-                 GParamSpec *pspec,
-                 gpointer user_data)
-{
-struct register_panel_data *data = user_data;
-
-	gboolean has_text;
-
-  has_text = gtk_entry_get_text_length (entry) > 0;
-  gtk_entry_set_icon_sensitive (entry,
-                                GTK_ENTRY_ICON_SECONDARY,
-                                has_text);
-
-	if(data->timer_tag == 0 )
-		data->timer_tag = g_timeout_add( DEFAULT_DELAY, quick_search_text_changed_timeout, (gpointer)user_data);
-
-
-	
-}
-
-static void
-quick_search_icon_press_cb (GtkEntry       *entry,
-               gint            position,
-               GdkEventButton *event,
-               gpointer        data)
-{
-  if (position == GTK_ENTRY_ICON_SECONDARY)
-    gtk_entry_set_text (entry, "");
 }
 
 
 static GtkActionEntry entries[] = {
 
 	/* name, icon-name, label */
-	{ "AccountMenu"	   , NULL, N_("_Account"), NULL, NULL, NULL },
-	{ "TxnMenu"        , NULL, N_("Transacti_on"), NULL, NULL, NULL },
-	{ "TxnStatusMenu"  , NULL, N_("_Status"), NULL, NULL, NULL },
-	{ "ActionsMenu"	   , NULL, N_("_Actions"), NULL, NULL, NULL },
-	{ "ToolsMenu"	   , NULL, N_("_Tools"), NULL, NULL, NULL },
+	{ "AccountMenu"	 , NULL, N_("A_ccount"), NULL, NULL, NULL },
+	{ "TxnMenu"      , NULL, N_("Transacti_on"), NULL, NULL, NULL },
+	{ "TxnStatusMenu", NULL, N_("_Status"), NULL, NULL, NULL },
+	{ "ToolsMenu"	 , NULL, N_("_Tools"), NULL, NULL, NULL },
 
-	{ "Close"			, ICONNAME_CLOSE	     , N_("_Close")				, "<control>W", N_("Close the current account"),		G_CALLBACK (register_panel_action_close) },
+	{ "Close" 	    , ICONNAME_CLOSE	        , N_("_Close")				, "<control>W", N_("Close the current account"),		G_CALLBACK (register_panel_action_close) },
 
 	/* name, icon-name, label, accelerator, tooltip */
-	{ "Filter"			, ICONNAME_HB_FILTER     , N_("_Filter..."), NULL,		N_("Open the list filter"), G_CALLBACK (register_panel_action_editfilter) },
-	{ "ConvToEuro"		, NULL                   , N_("Convert to euro..."), NULL,		N_("Convert this account to euro"), G_CALLBACK (register_panel_action_converttoeuro) },
+	{ "Filter"		, ICONNAME_HB_FILTER        , N_("_Filter..."), NULL,			N_("Open the list filter"), G_CALLBACK (register_panel_action_editfilter) },
+	{ "ConvToEuro"	, NULL                      , N_("Convert to Euro..."), NULL,	N_("Convert this account to Euro currency"), G_CALLBACK (register_panel_action_converttoeuro) },
 
-	{ "Add"				, ICONNAME_HB_OPE_ADD	 , N_("_Add..."), NULL,		N_("Add a new transaction"), G_CALLBACK (register_panel_action_add) },
-	{ "Inherit"			, ICONNAME_HB_OPE_HERIT	 , N_("_Inherit..."), NULL, N_("Inherit from the active transaction"), G_CALLBACK (register_panel_action_inherit) },
-	{ "Edit"			, ICONNAME_HB_OPE_EDIT	 , N_("_Edit..."), NULL, N_("Edit the active transaction"),	G_CALLBACK (register_panel_action_edit) },	
+	{ "Add"			, ICONNAME_HB_OPE_ADD	    , N_("_Add..."), NULL,		N_("Add a new transaction"), G_CALLBACK (register_panel_action_add) },
+	{ "Inherit"		, ICONNAME_HB_OPE_HERIT	    , N_("_Inherit..."), NULL, N_("Inherit from the active transaction"), G_CALLBACK (register_panel_action_inherit) },
+	{ "Edit"		, ICONNAME_HB_OPE_EDIT	    , N_("_Edit..."), NULL, N_("Edit the active transaction"),	G_CALLBACK (register_panel_action_edit) },
 
-	{ "None"	    	, NULL                   , N_("_None"), "<control>N",		N_("Toggle none for selected transaction(s)"), G_CALLBACK (register_panel_action_none) },
-	{ "Cleared"	    	, ICONNAME_HB_OPE_CLEARED, N_("_Cleared"), "<control>C",		N_("Toggle cleared for selected transaction(s)"), G_CALLBACK (register_panel_action_clear) },
-	{ "Reconciled"		, ICONNAME_HB_OPE_RECONCILED, N_("_Reconciled"), "<control>R",		N_("Toggle reconciled for selected transaction(s)"), G_CALLBACK (register_panel_action_reconcile) },
+	{ "None"	    , NULL                      , N_("_None"), "<control>N",		N_("Toggle none for selected transaction(s)"), G_CALLBACK (register_panel_action_none) },
+	{ "Cleared"	    , ICONNAME_HB_OPE_CLEARED   , N_("_Cleared"), "<control>C",		N_("Toggle cleared for selected transaction(s)"), G_CALLBACK (register_panel_action_clear) },
+	{ "Reconciled"	, ICONNAME_HB_OPE_RECONCILED, N_("_Reconciled"), "<control>R",		N_("Toggle reconciled for selected transaction(s)"), G_CALLBACK (register_panel_action_reconcile) },
 
 	{ "MultiEdit"	, ICONNAME_HB_OPE_MULTIEDIT , N_("_Multiple Edit..."), NULL, N_("Edit multiple transaction"),	G_CALLBACK (register_panel_action_multiedit) },
-	{ "Template"    	, ICONNAME_CONVERT       , N_("Create template..."), NULL,		N_("Create template"), G_CALLBACK (register_panel_action_createtemplate) },
-	{ "Delete"			, ICONNAME_HB_OPE_DELETE , N_("_Delete..."), NULL,		N_("Delete selected transaction(s)"), G_CALLBACK (register_panel_action_remove) },
+	{ "Template"    , ICONNAME_CONVERT          , N_("Create template..."), NULL,		N_("Create template"), G_CALLBACK (register_panel_action_createtemplate) },
+	{ "Delete"		, ICONNAME_HB_OPE_DELETE    , N_("_Delete..."), NULL,		N_("Delete selected transaction(s)"), G_CALLBACK (register_panel_action_remove) },
 
-	{ "Assign"			, ICONNAME_HB_ASSIGN_RUN , N_("Auto. Assignments"), NULL,		N_("Run auto assignments"), G_CALLBACK (register_panel_action_assign) },
-	{ "ExportQIF"		, NULL						, N_("Export QIF..."), NULL,		N_("Export as QIF"), G_CALLBACK (register_panel_action_exportqif) },
-	{ "ExportCSV"		, NULL						, N_("Export CSV..."), NULL,		N_("Export as CSV"), G_CALLBACK (register_panel_action_exportcsv) },
+	{ "Assign"		, ICONNAME_HB_ASSIGN_RUN    , N_("Auto. assignments"), NULL,	N_("Run automatic assignments"), G_CALLBACK (register_panel_action_assign) },
+	{ "ExportQIF"	, NULL						, N_("Export QIF..."), NULL,		N_("Export as QIF"), G_CALLBACK (register_panel_action_exportqif) },
+	{ "ExportCSV"	, NULL				   		, N_("Export CSV..."), NULL,		N_("Export as CSV"), G_CALLBACK (register_panel_action_exportcsv) },
 
 	{ "ChkIntXfer"  , NULL                      , N_("Check internal xfer..."), NULL,	NULL, G_CALLBACK (register_panel_action_check_internal_xfer) },
 
@@ -2150,17 +2229,15 @@ static const gchar *ui_info =
 "		<menuitem action='Delete'/>"
 "	</menu>"
 
-"	<menu action='ActionsMenu'>"
+"	<menu action='ToolsMenu'>"
+"		<menuitem action='Filter'/>"
 "		<menuitem action='Assign'/>"
 "			<separator/>"
 "		<menuitem action='ChkIntXfer'/>"
-"	</menu>"
 
-"		<menu action='ToolsMenu'>"
-"			<menuitem action='Filter'/>"
-"				<separator/>"
-"			<menuitem action='ConvToEuro'/>"
-"		</menu>"
+"	    	<separator/>"
+"		<menuitem action='ConvToEuro'/>"
+"	</menu>"
 "</menubar>"
 
 "<toolbar name='TxnBar'>"
@@ -2334,17 +2411,12 @@ GError *error = NULL;
 	gtk_grid_attach (GTK_GRID(table), widget, 9, 0, 1, 1);
 
 	//quick search
-	widget = gtk_entry_new ();
+	widget = make_search (NULL);
 	data->ST_search = widget;
-	gtk_entry_set_icon_from_icon_name (GTK_ENTRY (widget), GTK_ENTRY_ICON_PRIMARY, ICONNAME_FIND);
-	gtk_entry_set_icon_from_icon_name (GTK_ENTRY (widget), GTK_ENTRY_ICON_SECONDARY, ICONNAME_CLEAR);
 	gtk_widget_set_size_request(widget, HB_MINWIDTH_SEARCH, -1);
 	gtk_grid_attach (GTK_GRID(table), widget, 12, 0, 1, 1);
 
-	g_signal_connect (widget, "activate", G_CALLBACK (quick_search_activate_cb), data);
-	data->handler_id[HID_SEARCH] = g_signal_connect (widget, "notify::text", G_CALLBACK (quick_search_text_changed_cb), data);
-	g_signal_connect (widget, "icon-press", G_CALLBACK (quick_search_icon_press_cb), data);
-
+	data->handler_id[HID_SEARCH] = g_signal_connect (data->ST_search, "search-changed", G_CALLBACK (quick_search_text_changed_cb), data);
 	
 	// windows interior
 	table = gtk_grid_new();
@@ -2369,12 +2441,12 @@ GError *error = NULL;
 	data->CY_status = make_cycle(label, CYA_FLT_STATUS);
 	gtk_grid_attach (GTK_GRID(table), data->CY_status, 5, 0, 1, 1);
 
-	widget = gtk_button_new_with_mnemonic (_("Reset _Filters"));
+	widget = gtk_button_new_with_mnemonic (_("Reset _filters"));
 	data->BT_reset = widget;
 	gtk_grid_attach (GTK_GRID(table), widget, 6, 0, 1, 1);
 
 	//TRANSLATORS: this is for Euro specific users, a toggle to display in 'Minor' currency
-	widget = gtk_check_button_new_with_mnemonic (_("_Minor currency"));
+	widget = gtk_check_button_new_with_mnemonic (_("Euro _minor"));
 	data->CM_minor = widget;
 	gtk_grid_attach (GTK_GRID(table), widget, 8, 0, 1, 1);
 
