@@ -30,6 +30,7 @@
 #include "ui-assist-import.h"
 #include "ui-assist-start.h"
 #include "ui-account.h"
+#include "ui-currency.h"
 #include "ui-payee.h"
 #include "ui-category.h"
 #include "ui-archive.h"
@@ -81,6 +82,7 @@ static void ui_mainwindow_action_properties(void);
 static void ui_mainwindow_action_close(void);
 static void ui_mainwindow_action_quit(void);
 
+static void ui_mainwindow_action_defcurrency(void);
 static void ui_mainwindow_action_defaccount(void);
 static void ui_mainwindow_action_defpayee(void);
 static void ui_mainwindow_action_defcategory(void);
@@ -171,12 +173,12 @@ static GtkActionEntry entries[] = {
   { "New"        , ICONNAME_NEW            , N_("_New")          , "<control>N", N_("Create a new file"),    G_CALLBACK (ui_mainwindow_action_new) },
   { "Open"       , ICONNAME_OPEN           , N_("_Open...")      , "<control>O", N_("Open a file"),    G_CALLBACK (ui_mainwindow_action_open) },
   { "Save"       , ICONNAME_SAVE           , N_("_Save")         , "<control>S", N_("Save the current file"),    G_CALLBACK (ui_mainwindow_action_save) },
-  { "SaveAs"     , ICONNAME_SAVE_AS        , N_("Save As...")    , "<shift><control>S", N_("Save the current file with a different name"),    G_CALLBACK (ui_mainwindow_action_saveas) },
+  { "SaveAs"     , ICONNAME_SAVE_AS        , N_("Save _As...")    , "<shift><control>S", N_("Save the current file with a different name"),    G_CALLBACK (ui_mainwindow_action_saveas) },
   { "Revert"     , ICONNAME_REVERT         , N_("Revert")        , NULL, N_("Revert to a saved version of this file"),    G_CALLBACK (ui_mainwindow_action_revert) },
 
-  { "Properties" , ICONNAME_PROPERTIES     , N_("_Properties..."), NULL, N_("Configure the file"),    G_CALLBACK (ui_mainwindow_action_properties) },
+  { "Properties" , ICONNAME_PROPERTIES     , N_("Properties..."), NULL, N_("Configure the file"),    G_CALLBACK (ui_mainwindow_action_properties) },
   { "Close"      , ICONNAME_CLOSE          , N_("_Close")        , "<control>W", N_("Close the current file"),    G_CALLBACK (ui_mainwindow_action_close) },
-  { "Quit"       , ICONNAME_QUIT           , N_("_Quit")         , "<control>Q", N_("Quit homebank"),    G_CALLBACK (ui_mainwindow_action_quit) },
+  { "Quit"       , ICONNAME_QUIT           , N_("_Quit")         , "<control>Q", N_("Quit HomeBank"),    G_CALLBACK (ui_mainwindow_action_quit) },
 
   /* Exchange */
   { "ImportQIF" , ICONNAME_HB_FILE_IMPORT  , N_("QIF file...")     , NULL, N_("Open the import assistant"),    G_CALLBACK (ui_mainwindow_action_import) },
@@ -186,10 +188,10 @@ static GtkActionEntry entries[] = {
   { "ExportQIF" , ICONNAME_HB_FILE_EXPORT  , N_("Export QIF file...")     , NULL, N_("Export all account in a QIF file"),    G_CALLBACK (ui_mainwindow_action_export) },
 
   /* EditMenu */
-  { "Preferences", ICONNAME_PREFERENCES    , N_("Preferences..."), NULL,    N_("Configure homebank"),    G_CALLBACK (ui_mainwindow_action_preferences) },
+  { "Preferences", ICONNAME_PREFERENCES    , N_("Preferences..."), NULL,    N_("Configure HomeBank"),    G_CALLBACK (ui_mainwindow_action_preferences) },
 
   /* ManageMenu */
-//  { "Currency"   , ICONNAME_HB_CURRENCY    , N_("Currencies...") , NULL,    N_("Configure the currencies"), G_CALLBACK (ui_mainwindow_action_defcurrency) },
+  { "Currency"   , ICONNAME_HB_CURRENCY    , N_("Currencies...") , NULL,    N_("Configure the currencies"), G_CALLBACK (ui_mainwindow_action_defcurrency) },
   { "Account"    , ICONNAME_HB_ACCOUNT     , N_("Acc_ounts...")  , NULL,    N_("Configure the accounts"), G_CALLBACK (ui_mainwindow_action_defaccount) },
   { "Payee"      , ICONNAME_HB_PAYEE       , N_("_Payees...")    , NULL,    N_("Configure the payees"),    G_CALLBACK (ui_mainwindow_action_defpayee) },
   { "Category"   , ICONNAME_HB_CATEGORY    , N_("Categories...") , NULL,    N_("Configure the categories"),    G_CALLBACK (ui_mainwindow_action_defcategory) },
@@ -232,7 +234,7 @@ static GtkToggleActionEntry toggle_entries[] = {
   { "Toolbar"    , NULL                 , N_("_Toolbar")  , NULL,    NULL,    G_CALLBACK (ui_mainwindow_action_toggle_toolbar), TRUE },
   { "Spending"   , NULL                 , N_("_Top spending") , NULL,    NULL,    G_CALLBACK (ui_mainwindow_action_toggle_topspending), TRUE },
   { "Upcoming"   , NULL                 , N_("_Scheduled list") , NULL,    NULL,    G_CALLBACK (ui_mainwindow_action_toggle_upcoming), TRUE },
-  { "AsMinor"    , NULL                 , N_("Minor currency"), "<control>M",    NULL,    G_CALLBACK (ui_mainwindow_action_toggle_minor), FALSE },
+  { "AsMinor"    , NULL                 , N_("Euro minor"), "<control>M",    NULL,    G_CALLBACK (ui_mainwindow_action_toggle_minor), FALSE },
 };
 
 static guint n_toggle_entries = G_N_ELEMENTS (toggle_entries);
@@ -282,7 +284,7 @@ static const gchar *ui_info =
 "      <menuitem action='Archive'/>"
 "      <menuitem action='Budget'/>"
 "      <menuitem action='Assign'/>"
-//"      <menuitem action='Currency'/>"
+"      <menuitem action='Currency'/>"
 "    </menu>"
 "    <menu action='TxnMenu'>"
 "      <menuitem action='ShowOpe'/>"
@@ -320,13 +322,13 @@ static const gchar *ui_info =
 //	  here Open + recent is coded
 "    <toolitem action='Save'/>"
 "      <separator/>"
-//"    <toolitem action='Currency'/>"
 "    <toolitem action='Account'/>"
 "    <toolitem action='Payee'/>"
 "    <toolitem action='Category'/>"
 "    <toolitem action='Archive'/>"
 "    <toolitem action='Budget'/>"
 "    <toolitem action='Assign'/>"
+"    <toolitem action='Currency'/>"
 "      <separator/>"
 "    <toolitem action='ShowOpe'/>"
 "    <toolitem action='AddOpe'/>"
@@ -449,7 +451,7 @@ gchar *version;
 	
 	//gtk_about_dialog_set_wrap_license(GTK_ABOUT_DIALOG(dialog), );
 	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(dialog), "http://homebank.free.fr");
-	//gtk_about_dialog_set_website_label(GTK_ABOUT_DIALOG(dialog), "Visit the HomeBank website");
+	gtk_about_dialog_set_website_label(GTK_ABOUT_DIALOG(dialog), "Visit the HomeBank website");
 
 	gtk_about_dialog_set_logo_icon_name(GTK_ABOUT_DIALOG(dialog), "homebank");
 
@@ -580,13 +582,13 @@ gchar *secondtext;
 	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
 }
 
-/*
+
 static void ui_mainwindow_action_defcurrency(void)
 {
-	//ui_cur_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
+	ui_cur_manage_dialog();
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
 }
-*/
+
 
 static void ui_mainwindow_action_defaccount(void)
 {
@@ -708,7 +710,7 @@ struct hbfile_data *data = g_object_get_data(G_OBJECT(GLOBALS->mainwindow), "ins
 
 	// top spending
 	gtk_chart_show_minor(GTK_CHART(data->RE_pie), GLOBALS->minor);
-	hb_label_set_amount(GTK_LABEL(data->TX_topamount), data->toptotal, GLOBALS->minor);
+	hb_label_set_amount(GTK_LABEL(data->TX_topamount), data->toptotal, GLOBALS->kcur, GLOBALS->minor);
 
 }
 
@@ -893,7 +895,7 @@ GtkWidget *mainvbox, *widget, *label;
 	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
 	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome1), dialog);
 	
-	widget = gtk_button_new_with_mnemonic(_("Configure _Preferences"));
+	widget = gtk_button_new_with_mnemonic(_("Configure _preferences"));
 	gtk_box_pack_start (GTK_BOX (mainvbox), widget, FALSE, FALSE, 0);
 	g_signal_connect (widget, "clicked", G_CALLBACK (ui_mainwindow_action_help_welcome2), dialog);
 	
@@ -1139,7 +1141,7 @@ gint type, range;
 guint n_result, i, n_items;
 GArray *garray;
 gdouble total, other;
-//Account *acc;
+Account *acc;
 
 #define MAX_TOPSPENDING 5
 	
@@ -1170,6 +1172,7 @@ gdouble total, other;
 	if(garray)
 	{
 	struct tmptop zero = { .key=0, .value=0.0 };
+	GQueue *txn_queue;
 		
 		//DB( g_print(" - array length=%d\n", garray->len) );
 
@@ -1184,70 +1187,70 @@ gdouble total, other;
 
 		//DB( g_print("\n - end array length=%d\n", garray->len) );
 
+		//todo: not ideal, has ot force to get_acc for each txn below
+		txn_queue = hbfile_transaction_get_partial(data->filter->mindate, data->filter->maxdate);
+
 		/* compute the results */
-		list = g_list_first(GLOBALS->ope_list);
+		list = g_queue_peek_head_link(txn_queue);
 		while (list != NULL)
 		{
 		Transaction *ope = list->data;
-		Account *acc;
-			//debug
+
 			//DB( g_print(" - eval txn: '%s', cat=%d ==> flt-test=%d\n", ope->wording, ope->kcat, filter_test(data->filter, ope)) );
-			acc = da_acc_get(ope->kacc);
-			if(acc == NULL) goto next1;
-			if((acc->flags & (AF_CLOSED|AF_NOREPORT))) goto next1;
-			if(ope->paymode == PAYMODE_INTXFER) goto next1;
 
-			if( !(ope->status == TXN_STATUS_REMIND) )
+			if( !(ope->paymode == PAYMODE_INTXFER) )
 			{
-				if( (ope->date >= data->filter->mindate) && (ope->date <= data->filter->maxdate) )
+			guint32 pos = 0;
+			gdouble trn_amount;
+
+				//todo: optimize here
+				trn_amount = ope->amount;
+				acc = da_acc_get(ope->kacc);
+				if(acc)
+					trn_amount = hb_amount_base(ope->amount, acc->kcur);
+
+				if(  ope->flags & OF_SPLIT )
 				{
-				guint32 pos = 0;
-				gdouble trn_amount;
-
-					//trn_amount = to_base_amount(ope->amount, acc->kcur);
-					trn_amount = ope->amount;
-
-					if(  ope->flags & OF_SPLIT )
+				guint nbsplit = da_splits_count(ope->splits);
+				Split *split;
+				struct tmptop *item;
+				
+					for(i=0;i<nbsplit;i++)
 					{
-					guint nbsplit = da_transaction_splits_count(ope);
-					Split *split;
-					struct tmptop *item;
-					
-						for(i=0;i<nbsplit;i++)
-						{
-							split = ope->splits[i];
-							pos = category_report_id(split->kcat, type);
+						split = ope->splits[i];
+						pos = category_report_id(split->kcat, type);
 
-							//trn_amount = to_base_amount(split->amount, acc->kcur);
-							trn_amount = split->amount;
-							//#1297054 if( trn_amount < 0 ) {
-								item = &g_array_index (garray, struct tmptop, pos);
-								item->key = pos;
-								item->value += trn_amount;
-								DB( g_print(" - stored %.2f to item %d\n", trn_amount, pos)  );
-							//}
-						}
-					}
-					else
-					{
-					struct tmptop *item;
-
-						pos = category_report_id(ope->kcat, type);
-		
+						trn_amount = hb_amount_base(split->amount, acc->kcur);
+						//trn_amount = split->amount;
 						//#1297054 if( trn_amount < 0 ) {
 							item = &g_array_index (garray, struct tmptop, pos);
 							item->key = pos;
 							item->value += trn_amount;
-							DB( g_print(" - stored %.2f to item %d\n", trn_amount, pos)  );
+							//DB( g_print(" - stored %.2f to item %d\n", trn_amount, pos)  );
 						//}
 					}
-
 				}
+				else
+				{
+				struct tmptop *item;
+
+					pos = category_report_id(ope->kcat, type);
+	
+					//#1297054 if( trn_amount < 0 ) {
+						item = &g_array_index (garray, struct tmptop, pos);
+						item->key = pos;
+						item->value += trn_amount;
+						//DB( g_print(" - stored %.2f to item %d\n", trn_amount, pos)  );
+					//}
+				}
+
+
 			}
-next1:
+
 			list = g_list_next(list);
 		}
 
+		g_queue_free (txn_queue);
 		
 		// we need to sort this and limit before
 		g_array_sort(garray, (GCompareFunc)tmptop_compare_func);
@@ -1288,7 +1291,7 @@ next1:
 
 			if(!item->value) continue;
 
-			value = arrondi(item->value, 2);
+			value = hb_amount_round(item->value, 2);
 			entry = da_cat_get(item->key);
 			if(entry == NULL) continue;
 
@@ -1324,9 +1327,10 @@ next1:
 		g_object_unref(model);
 		
 		data->toptotal = total;
-		hb_label_set_amount(GTK_LABEL(data->TX_topamount), total, GLOBALS->minor);
+		hb_label_set_amount(GTK_LABEL(data->TX_topamount), total, GLOBALS->kcur, GLOBALS->minor);
 
 		gtk_chart_set_color_scheme(GTK_CHART(data->RE_pie), PREFS->report_color_scheme);
+		gtk_chart_set_currency(GTK_CHART(data->RE_pie), GLOBALS->kcur);
 		gtk_chart_set_datas(GTK_CHART(data->RE_pie), model, LST_TOPSPEND_AMOUNT, NULL, NULL);
 		//gtk_chart_show_legend(GTK_CHART(data->RE_pie), FALSE);
 
@@ -1604,6 +1608,7 @@ GDate *date;
 	while (list != NULL)
 	{
 	Archive *arc = list->data;
+	Account *acc;
 	gdouble inc, exp;
 	guint nbdays, nblate;
 
@@ -1615,26 +1620,28 @@ GDate *date;
 			
 			DB( g_print(" - append '%s' : %d\n", arc->wording, nbdays) );
 
-			//acc = da_acc_get(arc->kacc);
-			//total += to_base_amount(arc->amount, acc->kcur);
 			if(arc->flags & OF_INCOME)
 			{
 				inc = arc->amount;
 				exp = 0.0;
-				totinc += arc->amount;
 			}
 			else
 			{
 				exp = arc->amount;
 				inc = 0.0;
-				totexp += arc->amount;
 			}
 
 			/* insert normal txn */
+			acc = da_acc_get(arc->kacc);
+			if( acc)
+			{
+				totinc += hb_amount_base(inc, acc->kcur);
+				totexp += hb_amount_base(exp, acc->kcur);
+			}
 			gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 			gtk_list_store_set (GTK_LIST_STORE(model), &iter,
 				  LST_DSPUPC_DATAS, arc,
-				  LST_DSPUPC_ACCOUNT, arc->kacc,
+				  LST_DSPUPC_ACCOUNT, acc,
 			      LST_DSPUPC_WORDING, arc->wording,
 			      LST_DSPUPC_EXPENSE, exp,
 			      LST_DSPUPC_INCOME, inc,
@@ -1645,10 +1652,16 @@ GDate *date;
 			/* insert internal xfer txn : 1378836 */
 			if(arc->paymode == PAYMODE_INTXFER)
 			{
+				acc = da_acc_get(arc->kxferacc);
+				if( acc)
+				{
+					totinc += hb_amount_base(-inc, acc->kcur);
+					totexp += hb_amount_base(-exp, acc->kcur);
+				}
 				gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 				gtk_list_store_set (GTK_LIST_STORE(model), &iter,
 					  LST_DSPUPC_DATAS, arc,
-					  LST_DSPUPC_ACCOUNT, arc->kxferacc,
+					  LST_DSPUPC_ACCOUNT, acc,
 					  LST_DSPUPC_WORDING, arc->wording,
 					  LST_DSPUPC_EXPENSE, -inc,
 					  LST_DSPUPC_INCOME, -exp,
@@ -1667,6 +1680,7 @@ GDate *date;
 		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
 			  LST_DSPUPC_DATAS, NULL,
+			  LST_DSPUPC_ACCOUNT, NULL,
 			  LST_DSPUPC_WORDING, _("Total"),
 			  LST_DSPUPC_EXPENSE, totexp,
 		      LST_DSPUPC_INCOME, totinc,
@@ -1735,6 +1749,9 @@ gint r;
 			if(PREFS->appendscheduled)
 				scheduled_post_all_pending();
 
+			if(PREFS->do_update_currency)
+				ui_cur_manage_dialog_update_currencies(GTK_WINDOW(GLOBALS->mainwindow));
+
 			homebank_lastopenedfiles_save();
 
 			//todo: delete this after computing done at xml read
@@ -1824,7 +1841,7 @@ gint r = XML_UNSET;
 	}
 	else
 	{
-	gchar *msg = _("I/O error for file %s.");
+	gchar *msg = _("I/O error for file '%s'.");
 
 		ui_dialog_msg_infoerror(GTK_WINDOW(data->window), GTK_MESSAGE_ERROR,
 			_("File error"),
@@ -1907,18 +1924,12 @@ gdouble gtbank, gttoday, gtfuture;
 			{
 				acc = g_ptr_array_index(gpa, j);
 
-				//if(acc->kcur == GLOBALS->kcur)
-				//{
-					tbank += acc->bal_bank;
-					ttoday += acc->bal_today;
-					tfuture += acc->bal_future;
-				/*}
-				else
-				{
-					tbank += to_base_amount(acc->bal_bank, acc->kcur);
-					ttoday += to_base_amount(acc->bal_today, acc->kcur);
-					tfuture += to_base_amount(acc->bal_future, acc->kcur);
-				}*/
+				//tbank += acc->bal_bank;
+				//ttoday += acc->bal_today;
+				//tfuture += acc->bal_future;
+				tbank += hb_amount_base(acc->bal_bank, acc->kcur);
+				ttoday += hb_amount_base(acc->bal_today, acc->kcur);
+				tfuture += hb_amount_base(acc->bal_future, acc->kcur);
 
 				DB( g_print(" - insert '%s' :: %.2f %.2f %.2f\n", acc->name, acc->bal_bank, acc->bal_today, acc->bal_future) );
 
@@ -2139,10 +2150,10 @@ gint flags;
 		else
 			gtk_toolbar_set_style(GTK_TOOLBAR(data->toolbar), PREFS->toolbar_style-1);
 
-		gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (data->LV_acc), PREFS->rules_hint);
+		gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (data->LV_acc), PREFS->grid_lines);
 		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_acc));
 
-		gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (data->LV_upc), PREFS->rules_hint);
+		gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (data->LV_upc), PREFS->grid_lines);
 		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_upc));
 
 		DB( g_print(" - show toolbar=%d\n", PREFS->wal_toolbar) );
@@ -2537,8 +2548,8 @@ GError *error = NULL;
 	action = gtk_action_group_get_action(action_group, "Open");
 	g_object_set(action, "short_label", _("Open"), NULL);
 
-	action = gtk_action_group_get_action(action_group, "Save");
-	g_object_set(action, "is_important", TRUE, NULL);
+	//action = gtk_action_group_get_action(action_group, "Save");
+	//g_object_set(action, "is_important", TRUE, NULL);
 
 	action = gtk_action_group_get_action(action_group, "Account");
 	g_object_set(action, "short_label", _("Account"), NULL);
@@ -2635,25 +2646,26 @@ GError *error = NULL;
 
 static GtkWidget *ui_mainwindow_create_youraccounts(struct hbfile_data *data)
 {
-GtkWidget *mainvbox, *align, *label, *widget, *sw;
+GtkWidget *mainvbox, *label, *widget, *sw;
 
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
-	label = make_label(_("Your accounts"), 0.0, 0.5);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
-	gtk_misc_set_padding (GTK_MISC(label), SPACING_SMALL, SPACING_SMALL/2);
+	label = make_label_group(_("Your accounts"));
+	gtk_widget_set_margin_top(GTK_WIDGET(label), SPACING_SMALL/2);
+	gtk_widget_set_margin_bottom(GTK_WIDGET(label), SPACING_SMALL/2);
+	gtk_widget_set_margin_start(GTK_WIDGET(label), SPACING_SMALL);
+	gtk_widget_set_margin_end(GTK_WIDGET(label), SPACING_SMALL);
     gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
 
-	align = gtk_alignment_new(0, 0, 1.0, 1.0);
-	// top, bottom, left, right
-	gtk_alignment_set_padding (GTK_ALIGNMENT(align), 0, SPACING_SMALL, 2*SPACING_SMALL, SPACING_SMALL);
-	gtk_box_pack_start (GTK_BOX (mainvbox), align, TRUE, TRUE, 0);
-
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_container_add (GTK_CONTAINER (align), sw);
-	
+	//gtk_widget_set_margin_top(GTK_WIDGET(sw), 0);
+	gtk_widget_set_margin_bottom(GTK_WIDGET(sw), SPACING_SMALL);
+	gtk_widget_set_margin_start(GTK_WIDGET(sw), 2*SPACING_SMALL);
+	gtk_widget_set_margin_end(GTK_WIDGET(sw), SPACING_SMALL);
+	gtk_box_pack_start (GTK_BOX (mainvbox), sw, TRUE, TRUE, 0);
+
 	widget = (GtkWidget *)create_list_account();
 	data->LV_acc = widget;
 	gtk_container_add (GTK_CONTAINER (sw), widget);
@@ -2665,23 +2677,25 @@ GtkWidget *mainvbox, *align, *label, *widget, *sw;
 static GtkWidget *ui_mainwindow_create_topspending(struct hbfile_data *data)
 {
 GtkWidget *mainvbox, *hbox, *vbox;
-GtkWidget *label, *align, *widget;
+GtkWidget *label, *widget;
 
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	data->GR_top = mainvbox;
 
-	label = make_label(_("Where your money goes"), 0.0, 0.5);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
-	gtk_misc_set_padding (GTK_MISC(label), SPACING_SMALL, SPACING_SMALL/2);
+	label = make_label_group(_("Where your money goes"));
+	gtk_widget_set_margin_top(GTK_WIDGET(label), SPACING_SMALL/2);
+	gtk_widget_set_margin_bottom(GTK_WIDGET(label), SPACING_SMALL/2);
+	gtk_widget_set_margin_start(GTK_WIDGET(label), SPACING_SMALL);
+	gtk_widget_set_margin_end(GTK_WIDGET(label), SPACING_SMALL);
     gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
 
-	align = gtk_alignment_new(0, 0, 1.0, 1.0);
-	// top, bottom, left, right
-	gtk_alignment_set_padding (GTK_ALIGNMENT(align), 0, SPACING_SMALL, 2*SPACING_SMALL, SPACING_SMALL);
-	gtk_box_pack_start (GTK_BOX (mainvbox), align, TRUE, TRUE, 0);
 
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
-	gtk_container_add (GTK_CONTAINER (align), vbox);
+	//gtk_widget_set_margin_top(GTK_WIDGET(vbox), 0);
+	gtk_widget_set_margin_bottom(GTK_WIDGET(vbox), SPACING_SMALL);
+	gtk_widget_set_margin_start(GTK_WIDGET(vbox), 2*SPACING_SMALL);
+	gtk_widget_set_margin_end(GTK_WIDGET(vbox), SPACING_SMALL);
+	gtk_box_pack_start (GTK_BOX (mainvbox), vbox, TRUE, TRUE, 0);
 	
 	/* total + date range */
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
@@ -2721,7 +2735,7 @@ GtkWidget *label, *align, *widget;
 	data->LV_top = widget;
 
 	gtk_chart_show_legend(GTK_CHART(data->RE_pie), TRUE, TRUE);
-	
+
 //		gtk_container_add (GTK_CONTAINER (sw), widget);
 
 	return mainvbox;
@@ -2731,7 +2745,7 @@ GtkWidget *label, *align, *widget;
 static GtkWidget *ui_mainwindow_scheduled_create(struct hbfile_data *data)
 {
 GtkWidget *mainvbox, *hbox, *vbox, *bbox, *sw, *tbar;
-GtkWidget *label, *align, *widget;
+GtkWidget *label, *widget;
 GtkToolItem *toolitem;
 	
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
@@ -2740,10 +2754,11 @@ GtkToolItem *toolitem;
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
     gtk_box_pack_start (GTK_BOX (mainvbox), hbox, FALSE, FALSE, 0);
 
-	label = make_label(_("Scheduled transactions"), 0.0, 0.5);
-	//gtk_label_set_angle(GTK_LABEL(label), 90.0);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
-	gtk_misc_set_padding (GTK_MISC(label), SPACING_SMALL, SPACING_SMALL/2);
+	label = make_label_group(_("Scheduled transactions"));
+	gtk_widget_set_margin_top(GTK_WIDGET(label), SPACING_SMALL/2);
+	gtk_widget_set_margin_bottom(GTK_WIDGET(label), SPACING_SMALL/2);
+	gtk_widget_set_margin_start(GTK_WIDGET(label), SPACING_SMALL);
+	gtk_widget_set_margin_end(GTK_WIDGET(label), SPACING_SMALL);
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	label = make_label(_("maximum post date"), 0.0, 0.7);
@@ -2755,13 +2770,12 @@ GtkToolItem *toolitem;
 	gimp_label_set_attributes (GTK_LABEL (label), PANGO_ATTR_SCALE, PANGO_SCALE_SMALL, -1);
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
-	align = gtk_alignment_new(0, 0, 1.0, 1.0);
-	// top, bottom, left, right
-	gtk_alignment_set_padding (GTK_ALIGNMENT(align), 0, SPACING_SMALL, 2*SPACING_SMALL, SPACING_SMALL);
-	gtk_box_pack_start (GTK_BOX (mainvbox), align, TRUE, TRUE, 0);
-
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	gtk_container_add (GTK_CONTAINER (align), vbox);
+	//gtk_widget_set_margin_top(GTK_WIDGET(vbox), 0);
+	gtk_widget_set_margin_bottom(GTK_WIDGET(vbox), SPACING_SMALL);
+	gtk_widget_set_margin_start(GTK_WIDGET(vbox), 2*SPACING_SMALL);
+	gtk_widget_set_margin_end(GTK_WIDGET(vbox), SPACING_SMALL);
+	gtk_box_pack_start (GTK_BOX (mainvbox), vbox, TRUE, TRUE, 0);
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
