@@ -238,9 +238,7 @@ ChartStack *chart = GTK_CHARTSTACK(object);
 static gchar *ui_chart_stack_print_int(ChartStack *chart, gdouble value)
 {
 
-	mystrfmon(chart->buffer, CHART_BUFFER_LENGTH-1, value, chart->minor);
-	//mystrfmon_int(chart->buffer, CHART_BUFFER_LENGTH-1, value, chart->minor);
-
+	hb_strfmon(chart->buffer, CHART_BUFFER_LENGTH-1, value, chart->kcur, chart->minor);
 	return chart->buffer;
 }
 
@@ -1260,11 +1258,18 @@ void ui_chart_stack_set_color_scheme(ChartStack * chart, gint index)
 /*
 ** set the minor parameters
 */
-void ui_chart_stack_set_minor_prefs(ChartStack * chart, gdouble rate, gchar *symbol)
+/*void ui_chart_stack_set_minor_prefs(ChartStack * chart, gdouble rate, gchar *symbol)
 {
 	g_return_if_fail (GTK_IS_CHARTSTACK (chart));
 
 	chart->minor_rate   = rate;
 	chart->minor_symbol = symbol;
+}*/
+
+void ui_chart_stack_set_currency(ChartStack * chart, guint32 kcur)
+{
+	g_return_if_fail (GTK_IS_CHARTSTACK (chart));
+
+	chart->kcur = kcur;
 }
 
