@@ -142,7 +142,7 @@ struct _GtkChart
 	gboolean	show_xval;
 	gboolean	show_mono;
 	gint		every_xval;
-	//guint32		kcur;
+	guint32		kcur;
 	gboolean	minor;
 	gdouble		minor_rate;
 	gchar		*minor_symbol;
@@ -218,7 +218,7 @@ void gtk_chart_set_datas(GtkChart *chart, GtkTreeModel *model, guint column, gch
 void gtk_chart_set_dualdatas(GtkChart *chart, GtkTreeModel *model, guint column1, guint column2, gchar *title, gchar *subtitle);
 
 void gtk_chart_set_minor_prefs(GtkChart * chart, gdouble rate, gchar *symbol);
-//void gtk_chart_set_currency(GtkChart * chart, guint32 kcur);
+void gtk_chart_set_currency(GtkChart * chart, guint32 kcur);
 
 void gtk_chart_set_overdrawn(GtkChart * chart, gdouble minimum);
 void gtk_chart_set_every_xval(GtkChart * chart, gint decay);
