@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -47,6 +47,10 @@ da_acc_free(Account *item)
 		g_free(item->name);
 		g_free(item->number);
 		g_free(item->bankname);
+		g_free(item->notes);
+		
+		g_queue_free (item->txn_queue);
+		
 		g_free(item);
 	}
 }
@@ -55,8 +59,12 @@ da_acc_free(Account *item)
 Account *
 da_acc_malloc(void)
 {
+Account *item;
+
 	DB( g_print("da_acc_malloc\n") );
-	return g_malloc0(sizeof(Account));
+	item = g_malloc0(sizeof(Account));
+	item->txn_queue = g_queue_new ();
+	return item;
 }
 
 
@@ -330,27 +338,65 @@ GList *list = g_hash_table_get_values(GLOBALS->h_acc);
 gboolean
 account_is_used(guint32 key)
 {
+Account *acc;
 GList *list;
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
+gboolean retval;
 
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
+	retval = FALSE;
+	lst_acc = NULL;
+
+	acc = da_acc_get(key);
+	if( g_queue_get_length(acc->txn_queue) > 0 )
 	{
-	Transaction *entry = list->data;
-		if( key == entry->kacc || key == entry->kxferacc)
-			return TRUE;
-		list = g_list_next(list);
+		retval = TRUE;
+		goto end;
+	}
+
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
+	{
+	Account *acc = lnk_acc->data;
+	
+		if(acc->key != key)
+		{
+			lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+			while (lnk_txn != NULL)
+			{
+			Transaction *entry = lnk_txn->data;
+			
+				if( key == entry->kxferacc)
+				{
+					retval = TRUE;
+					goto end;
+				}
+
+				lnk_txn = g_list_next(lnk_txn);
+			}
+		}
+		lnk_acc = g_list_next(lnk_acc);
 	}
 
 	list = g_list_first(GLOBALS->arc_list);
 	while (list != NULL)
 	{
 	Archive *entry = list->data;
+
 		if( key == entry->kacc || key == entry->kxferacc)
-			return TRUE;
+		{
+			retval = TRUE;
+			goto end;
+		}
+
 		list = g_list_next(list);
 	}
 
-	return FALSE;
+end:
+	g_list_free(lst_acc);
+
+	return retval;
 }
 
 
@@ -396,46 +442,62 @@ gchar *stripname = account_get_stripname(newname);
 	return FALSE;
 }
 
-/* when we change the currency of an account, we must ensure
- * xfer transaction account will be set to same currency
+
+/* 
+ * change the account currency
+ * change every txn to currency
+ * ensure dst xfer transaction account will be set to same currency
  */
- /*
-void account_set_currency(Account *item, guint32 kcur)
+void account_set_currency(Account *acc, guint32 kcur)
 {
 GList *list;
-Account *acc;
+Account *dstacc;
+gboolean *xfer_list;
+guint32 maxkey, i;
 
-	if(item->kcur != kcur)
+	DB( g_print("\n[account] set currency\n") );
+
+	if(acc->kcur == kcur)
 	{
-		item->kcur = kcur;
-	
-		list = g_list_first(GLOBALS->ope_list);
-		while (list != NULL)
+		DB( g_print(" - already ok, return\n") );
+		return;
+	}
+
+	DB( g_print(" - set for '%s'\n", acc->name)  );
+		
+	maxkey = da_acc_get_max_key () + 1;
+	xfer_list = g_malloc0(sizeof(gboolean) * maxkey );
+	DB( g_print(" - alloc for %d account\n", da_acc_length() ) );
+
+	list = g_queue_peek_head_link(acc->txn_queue);
+	while (list != NULL)
+	{
+	Transaction *txn = list->data;
+
+		txn->kcur = kcur;
+		if( (txn->paymode == PAYMODE_INTXFER) && (txn->kxferacc > 0) && (txn->kxfer > 0) )
 		{
-		Transaction *entry = list->data;
-			if(entry->paymode == PAYMODE_INTXFER)
-			{
-				if(entry->kacc == item->key)
-				{
-					// change target account
-					acc = da_acc_get (entry->kxferacc);
-					acc->kcur = kcur;
-				}
-				if(entry->kxferacc == item->key)
-				{
-					// change source account
-					acc = da_acc_get (entry->kacc);
-					acc->kcur = kcur;
-				}
-			}
-			
-			list = g_list_next(list);
+			xfer_list[txn->kxferacc] = TRUE;
+		}
+		list = g_list_next(list);
+	}
+
+	acc->kcur = kcur;
+	DB( g_print(" - '%s'\n", acc->name) );
+	
+	for(i=1;i<maxkey;i++)
+	{
+		DB( g_print(" - %d '%d'\n", i, xfer_list[i]) );
+		if( xfer_list[i] == TRUE )
+		{
+			dstacc = da_acc_get(i);
+			account_set_currency(dstacc, kcur);
 		}
 	}
-	
-}
-*/
 
+	g_free(xfer_list);
+
+}
 
 
 /**
@@ -506,37 +568,33 @@ gboolean account_balances_add(Transaction *trn)
 
 void account_compute_balances(void)
 {
-GList *lacc, *list;
-Account *acc;
-Transaction *trn;
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
 
 	DB( g_print("\naccount_compute_balances start\n") );
 
-	/* set initial amount */
-	lacc = list = g_hash_table_get_values(GLOBALS->h_acc);
-	while (list != NULL)
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
 	{
-		acc = list->data;
+	Account *acc = lnk_acc->data;
+	
+		/* set initial amount */
 		acc->bal_bank = acc->initial;
 		acc->bal_today = acc->initial;
 		acc->bal_future = acc->initial;
-		list = g_list_next(list);
-	}
-	g_list_free(lacc);
-
-
-	/* compute every transaction */
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
-	{
-		trn = list->data;
-
-		if(!(trn->status == TXN_STATUS_REMIND))
+		
+		/* add every txn */
+		lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+		while (lnk_txn != NULL)
 		{
-			account_balances_add(trn);
+			account_balances_add_internal(acc, lnk_txn->data);
+			lnk_txn = g_list_next(lnk_txn);
 		}
-		list = g_list_next(list);
+		
+		lnk_acc = g_list_next(lnk_acc);
 	}
+	g_list_free(lst_acc);
 
 	DB( g_print("\naccount_compute_balances end\n") );
 
@@ -545,26 +603,22 @@ Transaction *trn;
 
 void account_convert_euro(Account *acc)
 {
-GList *list;
+GList *lnk_txn;
 
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
+	lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+	while (lnk_txn != NULL)
 	{
-	Transaction *ope = list->data;
-	gdouble oldamount = ope->amount;
+	Transaction *txn = lnk_txn->data;
+	gdouble oldamount = txn->amount;
 
-		if(ope->kacc == acc->key)
-		{
-			ope->amount = amount_to_euro(oldamount);
-			
-			DB( g_print("%10.6f => %10.6f, %s\n", oldamount, ope->amount, ope->wording) );
-
-		}
-		list = g_list_next(list);
+		txn->amount = hb_amount_to_euro(oldamount);
+		DB( g_print("%10.6f => %10.6f, %s\n", oldamount, txn->amount, txn->wording) );
+		//todo: sync child xfer
+		lnk_txn = g_list_next(lnk_txn);
 	}
 
-	acc->initial = amount_to_euro(acc->initial);
-	acc->minimum = amount_to_euro(acc->minimum);
-
+	acc->initial = hb_amount_to_euro(acc->initial);
+	acc->warning = hb_amount_to_euro(acc->warning);
+	acc->minimum = hb_amount_to_euro(acc->minimum);
 }
 
