@@ -19,6 +19,7 @@
 
 #include "homebank.h"
 #include "hb-archive.h"
+#include "hb-split.h"
 
 /****************************************************************************/
 /* Debug macros                                                             */
@@ -51,6 +52,9 @@ Archive *new_item = g_memdup(src_item, sizeof(Archive));
 	{
 		//duplicate the string
 		new_item->wording = g_strdup(src_item->wording);
+		
+		if( da_splits_clone(src_item->splits, new_item->splits) > 0)
+			new_item->flags |= OF_SPLIT; //Flag that Splits are active
 	}
 	return new_item;
 }
@@ -62,6 +66,9 @@ void da_archive_free(Archive *item)
 		if(item->wording != NULL)
 			g_free(item->wording);
 
+		da_splits_free(item->splits);
+		//item->flags &= ~(OF_SPLIT); //Flag that Splits are cleared		
+		
 		g_free(item);
 	}
 }
@@ -109,7 +116,9 @@ Payee *pay;
 		item->kcat = 0;
 		GLOBALS->changes_count++;
 	}
-
+	
+	split_cat_consistency(item->splits);
+	
 	// check payee exists
 	pay = da_pay_get(item->kpay);
 	if(pay == NULL)
@@ -153,6 +162,9 @@ Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn)
 	else
 		arc->wording 		= g_strdup(_("(new archive)"));
 
+	if( da_splits_clone(txn->splits, arc->splits) > 0)
+		arc->flags |= OF_SPLIT; //Flag that Splits are active
+	
 	return arc;
 }
 
@@ -195,7 +207,7 @@ gboolean scheduled_is_postable(Archive *arc)
 {
 gdouble value;
 
-	value = arrondi(arc->amount, 2);
+	value = hb_amount_round(arc->amount, 2);
 	if( (arc->flags & OF_AUTO) && (arc->kacc > 0) && (value != 0.0) )
 		return TRUE;
 
@@ -252,9 +264,45 @@ gint shift;
 
 guint32 scheduled_get_latepost_count(Archive *arc, guint32 jrefdate)
 {
+guint32 curdate = jrefdate - arc->nextdate;
 guint32 nblate = 0;
-guint32 curdate;
+
+	/*
+	switch(arc->unit)
+	{
+		case AUTO_UNIT_DAY:
+			nbpost = (curdate / arc->every);
+			g_print("debug d: %d => %f\n", curdate, nbpost);
+			break;
+
+		case AUTO_UNIT_WEEK:
+			nbpost = (curdate / ( 7 * arc->every));
+			g_print("debug w: %d => %f\n", curdate, nbpost);
+			break;
+
+		case AUTO_UNIT_MONTH:
+			//approximate is sufficient
+			nbpost = (curdate / (( 365.2425 / 12) * arc->every));
+			g_print("debug m: %d => %f\n", curdate, nbpost);
+			break;
+
+		case AUTO_UNIT_YEAR:
+			//approximate is sufficient
+			nbpost = (curdate / ( 365.2425 * arc->every));
+			g_print("debug y: %d => %f\n", curdate, nbpost);
+			break;
+	}
+
+	nblate = floor(nbpost);
+
+	if(arc->flags & OF_LIMIT)
+		nblate = MIN(nblate, arc->limit);
 	
+	nblate = MIN(nblate, 11);
+	*/
+	
+
+	// pre 5.1 way
 	curdate = arc->nextdate;
 	while(curdate <= jrefdate)
 	{
