@@ -43,7 +43,7 @@ struct _archive
 	//guint32		kxfer;		//strong link xfer key
 	guint32		kxferacc;
 	
-	//Split		*splits[TXN_MAX_SPLIT+1];
+	Split		*splits[TXN_MAX_SPLIT+1];
 
 	guint32		nextdate;
 	gushort		every;
