@@ -130,69 +130,64 @@ gint i;
 
 static void filter_set_date_bounds(Filter *flt, guint32 kacc)
 {
-GList *list;
-gboolean accounts[da_acc_get_max_key ()+1];
-guint i;
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
 
 	DB( g_print("(filter) set date bounds %p\n", flt) );
 
-	//todo: get date of current account only when account 
-	//todo: don't consider closed account !!
-	//beware: g_list_last get into every node !!
-
 	flt->mindate = 0;
 	flt->maxdate = 0;
 
-	//if(g_list_length(GLOBALS->ope_list) > 0)
-	//{
-		// open/closed acccount vector
-		for(i=1;i<=da_acc_get_max_key ();i++)
-		{
-		Account * acc = da_acc_get(i);
-			if(acc)
-			{
-				accounts[i] = acc->flags & AF_CLOSED ? FALSE: TRUE;
-				//in case we focus on an account, consider the account as disabled
-				if(kacc != 0 && i != kacc)
-					accounts[i] = FALSE;
-
-				DB( g_print("acc '%s' %d\n", acc->name, accounts[i]) );
-			}
-		}
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
+	{
+	Account *acc = lnk_acc->data;
 	
-		//parse all: in waiting other storage, as g_list_last will do anyway
-		// find first no account closed account
-		list = g_list_first(GLOBALS->ope_list);
-
-		while (list != NULL)
+		if( !(acc->flags & AF_CLOSED) )
 		{
-		Transaction *item = list->data;
-
-			if(accounts[item->kacc] == TRUE)
-			{
-				if( flt->mindate == 0 )
-					flt->mindate = item->date;
-				else
-					flt->mindate = MIN(flt->mindate, item->date);
-
-				if( flt->maxdate == 0 )
-					flt->maxdate = item->date;
-				else
-					flt->maxdate = MAX(flt->maxdate, item->date);
+		Transaction *txn;
+		
+			DB( g_print(" - do '%s'\n", acc->name) );
 
+			lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+			if(lnk_txn) {
+				txn = lnk_txn->data;
+				if( (kacc == 0) || (txn->kacc == kacc) )
+				{
+					if( flt->mindate == 0 )
+						flt->mindate = txn->date;
+					else
+						flt->mindate = MIN(flt->mindate, txn->date);
+				}
 			}
-			list = g_list_next(list);
-		}
-	//}
 
+			lnk_txn = g_queue_peek_tail_link(acc->txn_queue);
+			if(lnk_txn) {
+				txn = lnk_txn->data;
+				if( (kacc == 0) || (txn->kacc == kacc) )
+				{
+					if( flt->maxdate == 0 )
+						flt->maxdate = txn->date;
+					else
+						flt->maxdate = MAX(flt->maxdate, txn->date);
+				}
+			}
+
+		}
+		lnk_acc = g_list_next(lnk_acc);
+	}
+	
 	if( flt->mindate == 0 )
 		flt->mindate = HB_MINDATE;
 	
 	if( flt->maxdate == 0 )
 		flt->maxdate = HB_MAXDATE;	
 	
+	g_list_free(lst_acc);
 }
 
+
 void filter_preset_daterange_add_futuregap(Filter *filter, gint nbdays)
 {
 
@@ -380,8 +375,9 @@ GList *lcat, *list;
 	flt->option[FILTER_STATUS] = 0;
 	flt->reconciled = TRUE;
 	flt->cleared  = TRUE;
-	flt->forceadd = TRUE;
-	flt->forcechg = TRUE;
+	//#1602835 fautly set
+	//flt->forceadd = TRUE;
+	//flt->forcechg = TRUE;
 
 	flt->option[FILTER_CATEGORY] = 0;
 	lcat = list = g_hash_table_get_values(GLOBALS->h_cat);
@@ -475,7 +471,7 @@ gchar *tags;
 		guint count, i;
 		Split *split;
 
-			count = da_transaction_splits_count(txn);
+			count = da_splits_count(txn->splits);
 			for(i=0;i<count;i++)
 			{
 			gint tmpinsert = 0;
@@ -524,7 +520,7 @@ gchar *tags;
 		guint count, i;
 		Split *split;
 
-			count = da_transaction_splits_count(txn);
+			count = da_splits_count(txn->splits);
 			for(i=0;i<count;i++)
 			{
 			gint tmpinsert = 0;
@@ -636,7 +632,7 @@ gint insert;
 		Split *split;
 
 			insert = 0;	 //fix: 1151259
-			count = da_transaction_splits_count(txn);
+			count = da_splits_count(txn->splits);
 			for(i=0;i<count;i++)
 			{
 			gint tmpinsert = 0;
@@ -716,7 +712,7 @@ gint insert;
 			guint count, i;
 			Split *split;
 
-				count = da_transaction_splits_count(txn);
+				count = da_splits_count(txn->splits);
 				for(i=0;i<count;i++)
 				{
 				gint tmpinsert = 0;
