@@ -20,6 +20,7 @@
 #ifndef __HB_HBFILE_H__
 #define __HB_HBFILE_H__
 
+GQueue *hbfile_transaction_get_partial(guint32 minjulian, guint32 maxjulian);
 
 gboolean hbfile_file_hasbackup(gchar *filepath);
 
@@ -32,5 +33,8 @@ void hbfile_setup(gboolean file_clear);
 void hbfile_anonymize(void);
 void hbfile_sanity_check(void);
 
+void hbfile_change_basecurrency(guint32 key);
+void hbfile_replace_basecurrency(Currency4217 *curfmt);
+
 #endif
 
