@@ -758,7 +758,10 @@ GList *list = NULL;
 				}
 
 				hbs = da_split_new(kcat, s->amount, s->memo);
-				da_transaction_splits_append(newope, hbs);
+				
+				da_splits_append(newope->splits, hbs);
+				
+				//da_transaction_splits_append(newope, hbs);
 				hbs = NULL;				
 			}
 		}
