@@ -326,6 +326,8 @@ void
 payee_fill_usage(void)
 {
 GList *lpay;
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
 GList *lrul, *list;
 
 	lpay = list = g_hash_table_get_values(GLOBALS->h_pay);
@@ -338,17 +340,27 @@ GList *lrul, *list;
 	g_list_free(lpay);
 
 
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
 	{
-	Transaction *entry = list->data;
-	Payee *pay = da_pay_get (entry->kpay);
+	Account *acc = lnk_acc->data;
 
-		if(pay)
-			pay->usage_count++;
-		
-		list = g_list_next(list);
+		lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+		while (lnk_txn != NULL)
+		{
+		Transaction *txn = lnk_txn->data;
+		Payee *pay = da_pay_get (txn->kpay);
+			
+			if(pay)
+				pay->usage_count++;
+
+			lnk_txn = g_list_next(lnk_txn);
+		}
+
+		lnk_acc = g_list_next(lnk_acc);
 	}
+	g_list_free(lst_acc);
 
 
 	list = g_list_first(GLOBALS->arc_list);
@@ -381,19 +393,32 @@ GList *lrul, *list;
 void
 payee_move(guint32 key1, guint32 key2)
 {
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
 GList *lrul, *list;
 
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
 	{
-	Transaction *entry = list->data;
-		if(entry->kpay == key1)
+	Account *acc = lnk_acc->data;
+
+		lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+		while (lnk_txn != NULL)
 		{
-			entry->kpay = key2;
-			entry->flags |= OF_CHANGED;
+		Transaction *txn = lnk_txn->data;
+	
+			if(txn->kpay == key1)
+			{
+				txn->kpay = key2;
+				txn->flags |= OF_CHANGED;
+			}
+			lnk_txn = g_list_next(lnk_txn);
 		}
-		list = g_list_next(list);
+		lnk_acc = g_list_next(lnk_acc);
 	}
+	g_list_free(lst_acc);
+
 
 	list = g_list_first(GLOBALS->arc_list);
 	while (list != NULL)
