@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -71,11 +71,11 @@ Split *split = da_split_malloc();
 
 
 
-static Split *da_split_clone(Split *src_split)
+static Split *da_split_record_clone(Split *src_split)
 {
 Split *new_split = g_memdup(src_split, sizeof(Split));
 
-	DB( g_print("da_split_clone\n") );
+	DB( g_print("da_split_record_clone\n") );
 
 	if(new_split)
 	{
@@ -90,13 +90,13 @@ Split *new_split = g_memdup(src_split, sizeof(Split));
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
-guint da_transaction_splits_count(Transaction *txn)
+guint da_splits_count(Split *txn_splits[])
 {
 guint i, count = 0;
 
 	for(i=0;i<TXN_MAX_SPLIT;i++)
 	{
-		if(txn->splits[i] == NULL)
+		if(txn_splits[i] == NULL)
 			break;
 		count++;
 	}
@@ -104,67 +104,65 @@ guint i, count = 0;
 }
 
 
-void da_transaction_splits_free(Transaction *txn)
+void da_splits_free(Split *txn_splits[])
 {
 guint count, i=0;
 
-	count = da_transaction_splits_count(txn);
+	count = da_splits_count(txn_splits);
 	if(count == 0)
 		return;
 	
-	DB( g_print("da_transaction_splits_free\n") );
+	DB( g_print("da_splits_free\n") );
 
 	for(;i<=count;i++)
 	{
-		DB( g_print("- freeing %d :: %p\n", i, txn->splits[i]) );
+		DB( g_print("- freeing %d :: %p\n", i, txn_splits[i]) );
 		
-		da_split_free(txn->splits[i]);
-		txn->splits[i] = NULL;
+		da_split_free(txn_splits[i]);
+		txn_splits[i] = NULL;
 	}
-	//delete the flag
-	txn->flags &= ~(OF_SPLIT);
-
 }
 
 
-void da_transaction_splits_append(Transaction *txn, Split *split)
+void da_splits_append(Split *txn_splits[], Split *new_split)
 {
-guint count = da_transaction_splits_count(txn);
+guint count = da_splits_count(txn_splits);
 
-	DB( g_print("da_transaction_splits_append\n") );
+	DB( g_print("da_splits_append\n") );
 
-	DB( g_print("- split[%d] at %p for ope %p\n", count, split, txn) );
+	DB( g_print("- split[%d] at %p for ope \n", count, new_split) );
 
-	txn->flags |= OF_SPLIT;
-	txn->splits[count] = split;
-	txn->splits[count + 1] = NULL;
+	txn_splits[count] = new_split;
+	txn_splits[count + 1] = NULL;
 	
-	DB( g_print("- %d splits\n", da_transaction_splits_count(txn)) );
+	DB( g_print("- %d splits\n", da_splits_count(txn_splits)) );
 }
 
 
-void da_transaction_splits_clone(Transaction *stxn, Transaction *dtxn)
+guint da_splits_clone(Split *stxn_splits[], Split *dtxn_splits[])
 {
 gint i, count;
 
-	DB( g_print("da_transaction_splits_clone\n") );
+	DB( g_print("da_splits_clone\n") );
 	
-	count = da_transaction_splits_count(stxn);
+	count = da_splits_count(stxn_splits);
 	for(i=0;i<count;i++)
 	{
-		dtxn->splits[i] = da_split_clone(stxn->splits[i]);
+		dtxn_splits[i] = da_split_record_clone(stxn_splits[i]);
 	}	
 
-	if(count > 0)
-		dtxn->flags |= OF_SPLIT;
+/*	if(count > 0)
+		dtxn->flags |= OF_SPLIT;*/
 	
-	DB( g_print(" clone %p -> %p, %d splits\n", stxn, dtxn, count) );
+	DB( g_print(" clone %p -> %p, %d splits\n", stxn_splits, dtxn_splits, count) );
+	return count;
 }
 
 
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-guint transaction_splits_parse(Transaction *ope, gchar *cats, gchar *amounts, gchar *memos)
+guint da_splits_parse(Split *ope_splits[], gchar *cats, gchar *amounts, gchar *memos)
 {
 gchar **cat_a, **amt_a, **mem_a;
 guint count, i;
@@ -186,10 +184,9 @@ Split *split;
 			kcat = atoi(cat_a[i]);
 			amount = g_ascii_strtod(amt_a[i], NULL);
 			split = da_split_new(kcat, amount, mem_a[i]);
-			da_transaction_splits_append (ope, split);
+			da_splits_append (ope_splits, split);
 		}
 		
-		ope->flags |= OF_SPLIT;
 	}
 	else
 	{
@@ -205,22 +202,20 @@ Split *split;
 
 
 
-guint transaction_splits_tostring(Transaction *ope, gchar **cats, gchar **amounts, gchar **memos)
+guint da_splits_tostring(Split *ope_splits[], gchar **cats, gchar **amounts, gchar **memos)
 {
 guint count, i;
-Split *split;
 char buf[G_ASCII_DTOSTR_BUF_SIZE];
 GString *cat_a = g_string_new (NULL);
 GString *amt_a = g_string_new (NULL);
 GString *mem_a = g_string_new (NULL);
 
-	count = da_transaction_splits_count(ope);
+	count = da_splits_count(ope_splits);
 	for(i=0;i<count;i++)
 	{
-		split = ope->splits[i];
-		g_string_append_printf (cat_a, "%d", split->kcat);
-		g_string_append(amt_a, g_ascii_dtostr (buf, sizeof (buf), split->amount) );
-		g_string_append(mem_a, split->memo);
+		g_string_append_printf (cat_a, "%d", ope_splits[i]->kcat);
+		g_string_append(amt_a, g_ascii_dtostr (buf, sizeof (buf), ope_splits[i]->amount) );
+		g_string_append(mem_a, ope_splits[i]->memo);
 
 		if((i+1) < count)
 		{
@@ -237,4 +232,19 @@ GString *mem_a = g_string_new (NULL);
 	return count;
 }
 
+void split_cat_consistency (Split *txn_splits[])
+{
+	guint i, nbsplit;
+	
+	// check split category #1340142
+	nbsplit = da_splits_count(txn_splits);
+	for(i=0;i<nbsplit;i++)
+	{
+		if(da_cat_get(txn_splits[i]->kcat) == NULL)
+		{
+			g_warning("split consistency: fixed invalid split cat %d", txn_splits[i]->kcat);
+			txn_splits[i]->kcat = 0;
+		}
+	}
+}
 
