@@ -63,7 +63,8 @@ da_transaction_clean(Transaction *item)
 			item->tags = NULL;
 		}
 
-		da_transaction_splits_free(item);
+		da_splits_free(item->splits);
+		item->flags &= ~(OF_SPLIT); //Flag that Splits are cleared
 
 		if(item->same != NULL)
 		{
@@ -95,8 +96,6 @@ da_transaction_malloc(void)
 
 Transaction *da_transaction_copy(Transaction *src_txn, Transaction *dst_txn)
 {
-guint count;
-
 	DB( g_print("da_transaction_copy\n") );
 
 	da_transaction_clean (dst_txn);
@@ -108,13 +107,10 @@ guint count;
 	dst_txn->info = g_strdup(src_txn->info);
 
 	//duplicate tags
-	dst_txn->tags = NULL;
-	count = transaction_tags_count(src_txn);
-	if(count > 0)
-		//1501962: we must also copy the final 0
-		dst_txn->tags = g_memdup(src_txn->tags, (count+1)*sizeof(guint32));
+	transaction_tags_clone(src_txn, dst_txn);
 
-	da_transaction_splits_clone(src_txn, dst_txn);
+	if (da_splits_clone(src_txn->splits, dst_txn->splits) > 0)
+		dst_txn->flags |= OF_SPLIT; //Flag that Splits are active
 
 	return dst_txn;
 }
@@ -135,6 +131,8 @@ Transaction *da_transaction_init_from_template(Transaction *txn, Archive *arc)
 	txn->kxferacc	= arc->kxferacc;
 	txn->wording	= g_strdup(arc->wording);
 	txn->info		= NULL;
+	if( da_splits_clone(arc->splits, txn->splits) > 0)
+		txn->flags |= OF_SPLIT; //Flag that Splits are active
 
 	return txn;
 }
@@ -143,7 +141,6 @@ Transaction *da_transaction_init_from_template(Transaction *txn, Archive *arc)
 Transaction *da_transaction_clone(Transaction *src_item)
 {
 Transaction *new_item = g_memdup(src_item, sizeof(Transaction));
-guint count;
 
 	DB( g_print("da_transaction_clone\n") );
 
@@ -154,13 +151,10 @@ guint count;
 		new_item->info = g_strdup(src_item->info);
 
 		//duplicate tags
-		new_item->tags = NULL;
-		count = transaction_tags_count(src_item);
-		if(count > 0)
-			//1501962: we must also copy the final 0
-			new_item->tags = g_memdup(src_item->tags, (count+1)*sizeof(guint32));
-
-		da_transaction_splits_clone(src_item, new_item);
+		transaction_tags_clone(src_item, new_item);
+		
+		if( da_splits_clone(src_item->splits, new_item->splits) > 0)
+			new_item->flags |= OF_SPLIT; //Flag that Splits are active
 
 	}
 	return new_item;
@@ -177,24 +171,56 @@ da_transaction_new(void)
 guint
 da_transaction_length(void)
 {
-	return g_list_length(GLOBALS->ope_list);
-}
+GList *lst_acc, *lnk_acc;
+guint count = 0;
 
-
-void da_transaction_destroy(GList *list)
-{
-GList *tmplist = g_list_first(list);
-
-	while (tmplist != NULL)
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
 	{
-	Transaction *item = tmplist->data;
-		da_transaction_free(item);
-		tmplist = g_list_next(tmplist);
+	Account *acc = lnk_acc->data;
+	
+		count += g_queue_get_length (acc->txn_queue);
+		lnk_acc = g_list_next(lnk_acc);
 	}
-	g_list_free(list);
+	g_list_free(lst_acc);
+	return count;
 }
 
 
+static void da_transaction_queue_free_ghfunc(Transaction *item, gpointer data)
+{
+	da_transaction_free (item);
+}
+
+
+void da_transaction_destroy(void)
+{
+GList *lacc, *list;
+
+	lacc = g_hash_table_get_values(GLOBALS->h_acc);
+	list = g_list_first(lacc);
+	while (list != NULL)
+	{
+	Account *acc = list->data;
+
+		g_queue_foreach(acc->txn_queue, (GFunc)da_transaction_queue_free_ghfunc, NULL);
+		list = g_list_next(list);
+	}
+	g_list_free(lacc);
+}
+
+
+static gint da_transaction_compare_datafunc(Transaction *a, Transaction *b, gpointer data)
+{
+	return ((gint)a->date - b->date);
+}
+
+
+void da_transaction_queue_sort(GQueue *queue)
+{
+	g_queue_sort(queue, (GCompareDataFunc)da_transaction_compare_datafunc, NULL);
+}
 
 
 static gint da_transaction_compare_func(Transaction *a, Transaction *b)
@@ -224,21 +250,26 @@ static void da_transaction_insert_memo(Transaction *item)
 
 gboolean da_transaction_insert_sorted(Transaction *newitem)
 {
-GList *tmplist = g_list_first(GLOBALS->ope_list);
+Account *acc;
+GList *lnk_txn;
 
-	// find the breaking date
-	while (tmplist != NULL)
+	acc = da_acc_get(newitem->kacc);
+	if(!acc) 
+		return FALSE;
+	
+	lnk_txn = g_queue_peek_tail_link(acc->txn_queue);
+	while (lnk_txn != NULL)
 	{
-	Transaction *item = tmplist->data;
+	Transaction *item = lnk_txn->data;
 
-		if(item->date > newitem->date)
+		if(item->date <= newitem->date)
 			break;
-
-		tmplist = g_list_next(tmplist);
+		
+		lnk_txn = g_list_previous(lnk_txn);
 	}
 
-	// here we're at the insert point, let's insert our new txn just before
-	GLOBALS->ope_list = g_list_insert_before(GLOBALS->ope_list, tmplist, newitem);
+	// we're at insert point, insert after txn
+	g_queue_insert_after(acc->txn_queue, lnk_txn, newitem);
 
 	da_transaction_insert_memo(newitem);
 	return TRUE;
@@ -248,7 +279,12 @@ GList *tmplist = g_list_first(GLOBALS->ope_list);
 // nota: this is called only when loading xml file
 gboolean da_transaction_prepend(Transaction *item)
 {
-	GLOBALS->ope_list = g_list_prepend(GLOBALS->ope_list, item);
+Account *acc;
+
+	acc = da_acc_get(item->kacc);
+	if(acc)
+		item->kcur = acc->kcur;
+	g_queue_push_tail(acc->txn_queue, item);
 	da_transaction_insert_memo(item);
 	return TRUE;
 }
@@ -259,23 +295,33 @@ gboolean da_transaction_prepend(Transaction *item)
 static guint32
 da_transaction_get_max_kxfer(void)
 {
-guint32 max_key = 0;
+GList *lst_acc, *lnk_acc;
 GList *list;
-Transaction *item;
+guint32 max_key = 0;
 
 	DB( g_print("da_transaction_get_max_kxfer\n") );
 
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
 	{
-		item = list->data;
-		if( item->paymode == PAYMODE_INTXFER)
+	Account *acc = lnk_acc->data;
+
+		list = g_queue_peek_head_link(acc->txn_queue);
+		while (list != NULL)
 		{
-			if( item->kxfer > max_key)
-				max_key = item->kxfer;
+		Transaction *item = list->data;
+
+			if( item->paymode == PAYMODE_INTXFER )
+			{
+				max_key = MAX(max_key, item->kxfer);
+			}
+			list = g_list_next(list);
 		}
-		list = g_list_next(list);
+		
+		lnk_acc = g_list_next(lnk_acc);
 	}
+	g_list_free(lst_acc);
 
 	DB( g_print(" max_key : %d \n", max_key) );
 
@@ -304,7 +350,7 @@ void da_transaction_consistency(Transaction *item)
 Account *acc;
 Category *cat;
 Payee *pay;
-guint i, nbsplit;
+gint nbsplit;
 
 	// ensure date is between range
 	item->date = CLAMP(item->date, HB_MINDATE, HB_MAXDATE);
@@ -328,18 +374,10 @@ guint i, nbsplit;
 	}
 
 	// check split category #1340142
-	nbsplit = da_transaction_splits_count(item);
-	for(i=0;i<nbsplit;i++)
-	{
-	Split *split = item->splits[i];
-		cat = da_cat_get(split->kcat);
-		if(cat == NULL)
-		{
-			g_warning("txn consistency: fixed invalid split cat %d", split->kcat);
-			split->kcat = 0;
-		}
-	}
-	//# 1416624 empty category when split + add control on kcat for v5.0.1
+	split_cat_consistency(item->splits);
+
+	//# 1416624 empty category when split
+	nbsplit = da_splits_count(item->splits);
 	if(nbsplit > 0 && item->kcat > 0)
 	{
 		g_warning("txn consistency: fixed invalid cat on split txn");
@@ -386,7 +424,6 @@ gchar swap;
 
 	if( ope->kxferacc > 0 )
 	{
-		
 		child = da_transaction_clone(ope);
 
 		ope->flags |= OF_CHANGED;
@@ -440,50 +477,73 @@ gboolean retval = FALSE;
 	if(stxn == dtxn)
 		return FALSE;
 
-	if( 
-		stxn->date == dtxn->date &&
-	    //stxn->kxferacc == dtxn->kacc &&
-		stxn->kacc != dtxn->kacc &&
+	/*g_print("test\n");
+
+	g_print(" %d %d %d %f %d\n", 
+		stxn->kcur, stxn->date, stxn->kacc, ABS(stxn->amount), stxn->kxfer );
+
+
+	g_print(" %d %d %d %f %d\n", 
+		dtxn->kcur, dtxn->date, dtxn->kacc, ABS(dtxn->amount), dtxn->kxfer );
+	*/
+
+	if( stxn->kcur == dtxn->kcur &&
+	    stxn->date == dtxn->date &&
+	    //v5.1 make no sense: stxn->kxferacc == dtxn->kacc &&
+	    stxn->kacc != dtxn->kacc &&
 	    ABS(stxn->amount) == ABS(dtxn->amount) &&
 	    dtxn->kxfer == 0)
 	{
 		retval = TRUE;
 	}
 
+	//g_print(" return %d\n", retval);
 	return retval;
 }
 
 
 static GList *transaction_xfer_child_might_list_get(Transaction *ope)
 {
-GList *list;
-GList *matchlist = NULL;
+GList *lst_acc, *lnk_acc;
+GList *list, *matchlist = NULL;
 
 	DB( g_print("\n[transaction]xfer_get_potential_child\n") );
 
-	//DB( g_print(" - search : %d %s %f %d=>%d\n", src->date, src->wording, src->amount, src->account, src->kxferacc) );
-
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
 	{
-	Transaction *item = list->data;
+	Account *acc = lnk_acc->data;
 
-		if( transaction_xfer_child_might(ope, item, 0) == TRUE )
+		if( !(acc->flags & AF_CLOSED) && (acc->key != ope->kacc) )
 		{
-			//DB( g_print(" - match : %d %s %f %d=>%d\n", item->date, item->wording, item->amount, item->account, item->kxferacc) );
-
-			matchlist = g_list_append(matchlist, item);
+			list = g_queue_peek_tail_link(acc->txn_queue);
+			while (list != NULL)
+			{
+			Transaction *item = list->data;
+	
+				// no need to go higher than src txn date
+				if(item->date < ope->date)
+					break;
+		
+				if( transaction_xfer_child_might(ope, item, 0) == TRUE )
+				{
+					//DB( g_print(" - match : %d %s %f %d=>%d\n", item->date, item->wording, item->amount, item->account, item->kxferacc) );
+					matchlist = g_list_append(matchlist, item);
+				}
+				list = g_list_previous(list);
+			}
 		}
-		list = g_list_next(list);
+		
+		lnk_acc = g_list_next(lnk_acc);
 	}
-
-	DB( g_print(" - found : %d\n", g_list_length(matchlist)) );
+	g_list_free(lst_acc);
 
 	return matchlist;
 }
 
 
-void transaction_xfer_search_or_add_child(GtkWindow *parentwindow, Transaction *ope)
+void transaction_xfer_search_or_add_child(GtkWindow *parentwindow, Transaction *ope, gboolean manual)
 {
 GList *matchlist;
 
@@ -517,9 +577,9 @@ GList *list;
 	if( !dstacc || src->kxfer <= 0 )
 		return NULL;
 
-	DB( g_print(" - search: %d %s %f %d=>%d\n", src->date, src->wording, src->amount, src->kacc, src->kxferacc) );
+	DB( g_print(" - search: %d %s %f %d=>%d - %d\n", src->date, src->wording, src->amount, src->kacc, src->kxferacc, src->kxfer) );
 
-	list = g_list_first(GLOBALS->ope_list);
+	list = g_queue_peek_tail_link(dstacc->txn_queue);
 	while (list != NULL)
 	{
 	Transaction *item = list->data;
@@ -532,10 +592,10 @@ GList *list;
 		 && item->kxfer == src->kxfer 
 		 && item != src )
 		{
-			DB( g_print(" - found : %d %s %f %d=>%d\n", item->date, item->wording, item->amount, item->kacc, item->kxferacc) );
+			DB( g_print(" - found : %d %s %f %d=>%d - %d\n", item->date, item->wording, item->amount, item->kacc, item->kxferacc, src->kxfer) );
 			return item;
 		}
-		list = g_list_next(list);
+		list = g_list_previous(list);
 	}
 	
 	DB( g_print(" - not found...\n") );
@@ -551,6 +611,9 @@ Account *dstacc;
 
 	DB( g_print("\n[transaction] transaction_xfer_change_to_child\n") );
 
+	if(ope->kcur != child->kcur)
+		return;
+
 	ope->flags |= OF_CHANGED;
 	child->flags |= OF_CHANGED;
 
@@ -601,7 +664,10 @@ void transaction_xfer_sync_child(Transaction *s_txn, Transaction *child)
 
 	account_balances_add (child);
 	
-	//todo: synchronise tags here also ?
+	//synchronise tags since 5.1
+	if(child->tags)
+		g_free(child->tags);
+	transaction_tags_clone (s_txn, child);
 
 }
 
@@ -618,11 +684,14 @@ Transaction *dst;
 
 	if( dst != NULL )
 	{
+	Account *acc = da_acc_get(dst->kacc);
+
 		DB( g_print("deleting...") );
 		src->kxfer = 0;
 		src->kxferacc = 0;
 		account_balances_sub(dst);
-		GLOBALS->ope_list = g_list_remove(GLOBALS->ope_list, dst);
+		g_queue_remove(acc->txn_queue, dst);
+		da_transaction_free (dst);
 	}
 }
 
@@ -630,13 +699,15 @@ Transaction *dst;
 // still useful for upgrade from < file v0.6 (hb v4.4 kxfer)
 Transaction *transaction_old_get_child_transfer(Transaction *src)
 {
+Account *acc;
 GList *list;
 
 	DB( g_print("\n[transaction] transaction_get_child_transfer\n") );
 
 	//DB( g_print(" search: %d %s %f %d=>%d\n", src->date, src->wording, src->amount, src->account, src->kxferacc) );
+	acc = da_acc_get(src->kxferacc);
 
-	list = g_list_first(GLOBALS->ope_list);
+	list = g_queue_peek_head_link(acc->txn_queue);
 	while (list != NULL)
 	{
 	Transaction *item = list->data;
@@ -680,13 +751,16 @@ Account *acc;
 	acc = da_acc_get(ope->kacc);
 	if(acc == NULL) return;
 
+	ope->kcur = acc->kcur;
+	
 	if(ope->paymode == PAYMODE_INTXFER)
 	{
 		acc = da_acc_get(ope->kxferacc);
 		if(acc == NULL) return;
 		
 		// delete any splits
-		da_transaction_splits_free(ope);
+		da_splits_free(ope->splits);
+		ope->flags &= ~(OF_SPLIT); //Flag that Splits are cleared
 	}
 
 	//allocate a new entry and copy from our edited structure
@@ -738,7 +812,7 @@ Account *acc;
 
 		if(newope->paymode == PAYMODE_INTXFER)
 		{
-			transaction_xfer_search_or_add_child(NULL, newope);
+			transaction_xfer_search_or_add_child(NULL, newope, FALSE);
 		}
 	}
 }
@@ -775,6 +849,30 @@ GtkTreeIter  iter;
 }
 
 
+gboolean transaction_acc_move(Transaction *txn, guint32 okacc, guint32 nkacc)
+{
+Account *oacc, *nacc;
+
+	oacc = da_acc_get(okacc);
+	nacc = da_acc_get(nkacc);
+	if( oacc && nacc )
+	{
+		if( g_queue_remove(oacc->txn_queue, txn) )
+		{
+			g_queue_push_tail(nacc->txn_queue, txn);
+			txn->kacc = nacc->key;
+			txn->kcur = nacc->kcur;
+			nacc->flags |= AF_CHANGED;
+			return TRUE;
+		}
+		else
+			//ensure to keep txn into current account
+			txn->kacc = okacc;
+	}
+	return FALSE;
+}
+
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
@@ -814,6 +912,22 @@ gboolean match = FALSE;
 	return match;
 }
 
+static gboolean misc_regex_match(gchar *text, gchar *searchtext, gboolean exact)
+{
+gboolean match = FALSE;
+
+	if(text == NULL)
+		return FALSE;
+	
+	DB( g_print("match RE %s in %s\n", searchtext, text) );
+	if( searchtext != NULL )
+	{
+		match = g_regex_match_simple(searchtext, text, ((exact == TRUE)?0:G_REGEX_CASELESS) | G_REGEX_OPTIMIZE, G_REGEX_MATCH_NOTEMPTY );
+		if (match == TRUE) { DB( g_print(" found pattern '%s'\n", searchtext) ); }
+	}
+	return match;
+}
+
 
 static Assign *transaction_auto_assign_eval_txn(GList *l_rul, Transaction *txn)
 {
@@ -835,8 +949,17 @@ GList *list;
 			if(pay)
 				text = pay->name;
 		}
-		if( misc_text_match(text, rul->name, rul->flags & ASGF_EXACT))
-			rule = rul;
+		
+		if( !(rul->flags & ASGF_REGEX) )
+		{
+			if( misc_text_match(text, rul->text, rul->flags & ASGF_EXACT) )
+				rule = rul;
+		}
+		else
+		{
+			if( misc_regex_match(text, rul->text, rul->flags & ASGF_EXACT) )
+				rule = rul;
+		}
 
 		list = g_list_next(list);
 	}
@@ -859,8 +982,16 @@ GList *list;
 
 		if( rul->field == 0 )   //memo
 		{
-			if( misc_text_match(text, rul->name, rul->flags & ASGF_EXACT))
-				rule = rul;
+			if( !(rul->flags & ASGF_REGEX) )
+			{
+				if( misc_text_match(text, rul->text, rul->flags & ASGF_EXACT) )
+					rule = rul;
+			}
+			else
+			{
+				if( misc_regex_match(text, rul->text, rul->flags & ASGF_EXACT) )
+					rule = rul;
+			}
 		}
 		list = g_list_next(list);
 	}
@@ -895,7 +1026,7 @@ gint changes = 0;
 			rul = transaction_auto_assign_eval_txn(l_rul, ope);
 			if( rul != NULL )
 			{
-				if( (ope->kpay == 0 || (rul->flags & ASGF_OVWPAY)) && (rul->flags & ASGF_DOPAY) )
+				if( (ope->kpay == 0 && (rul->flags & ASGF_DOPAY)) || (rul->flags & ASGF_OVWPAY) )
 				{
 					if(ope->kpay != rul->kpay) { changed = TRUE; }
 					ope->kpay = rul->kpay;
@@ -903,17 +1034,28 @@ gint changes = 0;
 
 				if( !(ope->flags & OF_SPLIT) )
 				{
-					if( (ope->kcat == 0 || (rul->flags & ASGF_OVWCAT)) && (rul->flags & ASGF_DOCAT) )
+					if( (ope->kcat == 0 && (rul->flags & ASGF_DOCAT)) || (rul->flags & ASGF_OVWCAT) )
 					{
 						if(ope->kcat != rul->kcat) { changed = TRUE; }
 						ope->kcat = rul->kcat;
 					}
 				}
+
+				if( (ope->paymode == 0 && (rul->flags & ASGF_DOMOD)) || (rul->flags & ASGF_OVWMOD) )
+				{
+					//ugly hack - don't allow modify intxfer
+					if(ope->paymode != PAYMODE_INTXFER && rul->paymode != PAYMODE_INTXFER) 
+					{
+						if(ope->paymode != rul->paymode) { changed = TRUE; }
+						ope->paymode = rul->paymode;
+					}
+				}
+
 			}
 
 			if( ope->flags & OF_SPLIT )
 			{
-			guint i, nbsplit = da_transaction_splits_count (ope);
+			guint i, nbsplit = da_splits_count(ope->splits);
 
 				for(i=0;i<nbsplit;i++)
 				{
@@ -971,9 +1113,18 @@ guint32 *ptr = ope->tags;
 }
 
 
+void transaction_tags_clone(Transaction *src_txn, Transaction *dst_txn)
+{
+guint count;
 
-
-
+	dst_txn->tags = NULL;
+	count = transaction_tags_count(src_txn);
+	if(count > 0)
+	{
+		//1501962: we must also copy the final 0
+		dst_txn->tags = g_memdup(src_txn->tags, (count+1)*sizeof(guint32));
+	}
+}
 
 guint
 transaction_tags_parse(Transaction *ope, const gchar *tagstring)
