@@ -21,12 +21,12 @@
 #ifndef __HB_TRANSACTION_H__
 #define __HB_TRANSACTION_H__
 
+#include "hb-split.h"
+
 
 typedef struct _transaction	Transaction;
 
 
-#include "hb-split.h"
-
 struct _transaction
 {
 	gdouble		amount;
@@ -49,7 +49,7 @@ struct _transaction
 
 	/* unsaved datas */
 	GList		*same;		//used for import todo: change this
-
+	guint32		kcur;
 	gdouble		balance;
 };
 
@@ -82,8 +82,9 @@ void da_transaction_clean(Transaction *item);
 void da_transaction_free(Transaction *item);
 
 GList *da_transaction_new(void);
-void da_transaction_destroy(GList *list);
+void da_transaction_destroy(void);
 
+void da_transaction_queue_sort(GQueue *queue);
 GList *da_transaction_sort(GList *list);
 gboolean da_transaction_prepend(Transaction *item);
 gboolean da_transaction_insert_sorted(Transaction *item);
@@ -104,14 +105,17 @@ guint da_transaction_length(void);
 void transaction_add_treeview(Transaction *ope, GtkWidget *treeview, guint32 accnum);
 void transaction_add(Transaction *ope, GtkWidget *treeview, guint32 accnum);
 
+gboolean transaction_acc_move(Transaction *txn, guint32 okacc, guint32 nkacc);
+
 Transaction *transaction_xfer_child_strong_get(Transaction *src);
-void transaction_xfer_search_or_add_child(GtkWindow *parentwindow, Transaction *ope);
+void transaction_xfer_search_or_add_child(GtkWindow *parentwindow, Transaction *ope, gboolean manual);
 void transaction_xfer_change_to_child(Transaction *ope, Transaction *child);
 void transaction_xfer_sync_child(Transaction *ope, Transaction *child);
 void transaction_xfer_remove_child(Transaction *src);
 Transaction *transaction_old_get_child_transfer(Transaction *src);
 
 guint transaction_tags_count(Transaction *ope);
+void transaction_tags_clone(Transaction *src_txn, Transaction *dst_txn);
 guint transaction_tags_parse(Transaction *ope, const gchar *tagstring);
 gchar *transaction_tags_tostring(Transaction *ope);
 gint transaction_auto_assign(GList *ope_list, guint32 key);
