@@ -458,7 +458,7 @@ homebank_theme_changed (GtkSettings *settings, GParamSpec  *pspec, gpointer
 
             if(provider != NULL)
             {
-                DB( g_print(" assign provider %p to sreen %p\n", provider, screen) );
+                DB( g_print(" assign provider %p to screen %p\n", provider, screen) );
 
                 gtk_style_context_add_provider_for_screen (screen,
                                        GTK_STYLE_PROVIDER (provider),
@@ -1042,6 +1042,9 @@ gboolean openlast;
 					ui_mainwindow_open_internal(mainwin, NULL);
 			}
 
+			/* -- hack to generate a big file -- */
+
+
 			/* update the mainwin display */
 			ui_mainwindow_update(mainwin, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE+UF_VISUAL));
 
