@@ -41,6 +41,7 @@
 #include "hb-preferences.h"
 
 #include "hb-transaction.h"
+#include "hb-currency.h"
 #include "hb-account.h"
 #include "hb-archive.h"
 #include "hb-assign.h"
@@ -70,14 +71,14 @@
 #define HB_UNSTABLE		FALSE
 
 #define HB_VERSION_MAJOR	5
-#define HB_VERSION_MINOR	0
-#define HB_VERSION_MICRO	9
+#define HB_VERSION_MINOR	1
+#define HB_VERSION_MICRO	1
 
-#define HB_VERSION			"5.0.9"
+#define HB_VERSION			"5.1.1"
 #define HB_VERSION_NUM	(HB_VERSION_MAJOR*10000) + (HB_VERSION_MINOR*100) + HB_VERSION_MICRO
 
-#define FILE_VERSION		1.1
-#define PREF_VERSION		500
+#define FILE_VERSION		1.2
+#define PREF_VERSION		510
 
 #if HB_UNSTABLE == FALSE
 	#define	PROGNAME		"HomeBank"
@@ -132,7 +133,7 @@
 #define HB_NUMBER_SAMPLE	1234567.89
 
 
-enum
+typedef enum
 {
 	FILETYPE_UNKNOW,
 	FILETYPE_HOMEBANK,
@@ -141,7 +142,8 @@ enum
 	FILETYPE_CSV_HB,
 //	FILETYPE_AMIGA_HB,
 	NUM_FILETYPE
-};
+} HbFileType;
+
 
 /* ---- icon size as defined into gtkiconfactory.c ---- */
 /* GTK_ICON_SIZE_MENU 16
@@ -174,8 +176,8 @@ enum
 
 #define ICONNAME_FOLDER				"folder-symbolic"
 
-
-
+#define ICONNAME_LIST_ADD			"list-add-symbolic"
+#define ICONNAME_LIST_REMOVE		"list-remove-symbolic"
 
 //#define ICONNAME_HB_SCHED_SKIP		"media-skip-forward"
 //#define ICONNAME_HB_SCHED_POST		"media-playback-start"
@@ -186,7 +188,7 @@ enum
 
 
 /* -------- named icons (Custom to homebank) -------- */
-
+#define ICONNAME_HB_CURRENCY		"hb-currency"
 #define ICONNAME_HB_ACCOUNT         "hb-account"
 #define ICONNAME_HB_ARCHIVE         "hb-archive"
 #define ICONNAME_HB_ASSIGN          "hb-assign"
@@ -243,7 +245,7 @@ enum
 struct HomeBank
 {
 	// hbfile storage
-	//GHashTable		*h_cur;			//currencies
+	GHashTable		*h_cur;			//currencies
 	GHashTable		*h_acc;			//accounts
 	GHashTable		*h_pay;			//payees
 	GHashTable		*h_cat;			//categories
@@ -253,7 +255,7 @@ struct HomeBank
 	GHashTable		*h_memo;		//memo/description
 
 	GList			*arc_list;		//archives
-	GList			*ope_list;		//transactions
+
 	//#1419304 we keep the deleted txn to a stack trash
 	GTrashStack		*txn_stk;
 
@@ -264,7 +266,7 @@ struct HomeBank
 	gshort			auto_nbdays;
 
 	guint32			vehicle_category;
-	//guint32		kcur;			// base currency
+	guint32			kcur;			// base currency
 
 	// hbfile (unsaved properties)
 	guint			changes_count;
