@@ -66,7 +66,7 @@ static GtkActionEntry entries[] = {
   { "Column"  , ICONNAME_HB_VIEW_COLUMN , N_("Column") , NULL,    N_("View results as column"), G_CALLBACK (ui_repdist_action_viewbar) },
   { "Donut"   , ICONNAME_HB_VIEW_DONUT  , N_("Donut")  , NULL,    N_("View results as donut"), G_CALLBACK (ui_repdist_action_viewpie) },
 
-  { "Filter"  , ICONNAME_HB_FILTER      , N_("Filter") , NULL,   N_("Edit the filter"), G_CALLBACK (ui_repdist_action_filter) },
+  { "Filter"  , ICONNAME_HB_FILTER      , N_("Filter") , NULL,   N_("Edit filter"), G_CALLBACK (ui_repdist_action_filter) },
   { "Refresh" , ICONNAME_REFRESH        , N_("Refresh"), NULL,   N_("Refresh results"), G_CALLBACK (ui_repdist_action_refresh) },
 
   { "Export"  , ICONNAME_HB_FILE_EXPORT , N_("Export")  , NULL,   N_("Export as CSV"), G_CALLBACK (ui_repdist_action_export) },
@@ -446,65 +446,39 @@ GtkTreeIter  iter;
 		gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_detail), NULL); /* Detach model from view */
 
 		/* fill in the model */
-		list = g_list_first(GLOBALS->ope_list);
+		list = g_queue_peek_head_link(data->txn_queue);
 		while (list != NULL)
 		{
 		Transaction *ope = list->data;
-		Account *acc;
 
-			//DB( g_print(" get %s\n", ope->ope_Word) );
-
-			acc = da_acc_get(ope->kacc);
-			if(acc == NULL) goto next1;
-			if((acc->flags & (AF_CLOSED|AF_NOREPORT))) goto next1;
-
-			//filter here
-			if( !(ope->status == TXN_STATUS_REMIND) )
+			if(filter_test(data->filter, ope) == 1)
 			{
-				if(filter_test(data->filter, ope) == 1)
+			guint i, pos = 0;
+
+				if( tmpfor != BY_REPDIST_TAG )
 				{
-				guint i, pos = 0;
-
-					if( tmpfor != BY_REPDIST_TAG )
+					if( (tmpfor == BY_REPDIST_CATEGORY || tmpfor == BY_REPDIST_SUBCATEGORY) && ope->flags & OF_SPLIT )
 					{
-						if( (tmpfor == BY_REPDIST_CATEGORY || tmpfor == BY_REPDIST_SUBCATEGORY) && ope->flags & OF_SPLIT )
+					guint nbsplit = da_splits_count(ope->splits);
+					Split *split;
+					
+						for(i=0;i<nbsplit;i++)
 						{
-						guint nbsplit = da_transaction_splits_count(ope);
-						Split *split;
-						
-							for(i=0;i<nbsplit;i++)
+							split = ope->splits[i];
+							switch(tmpfor)
 							{
-								split = ope->splits[i];
-								switch(tmpfor)
-								{
-									case BY_REPDIST_CATEGORY:
-										{
-										Category *catentry = da_cat_get(split->kcat);
-											if(catentry)
-												pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
-										}
-										break;
-									case BY_REPDIST_SUBCATEGORY:
-										pos = split->kcat;
-										break;
-								}
-
-								if( pos == active )
-								{
-
-									gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-							 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-										LST_DSPOPE_DATAS, ope,
-										-1);
-										
+								case BY_REPDIST_CATEGORY:
+									{
+									Category *catentry = da_cat_get(split->kcat);
+										if(catentry)
+											pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
+									}
+									break;
+								case BY_REPDIST_SUBCATEGORY:
+									pos = split->kcat;
 									break;
-								}
-
 							}
-						}
-						else
-						{
-							pos = ui_repdist_result_get_pos(tmpfor, data->filter->mindate, ope);
+
 							if( pos == active )
 							{
 
@@ -512,44 +486,59 @@ GtkTreeIter  iter;
 						 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
 									LST_DSPOPE_DATAS, ope,
 									-1);
-
+									
+								break;
 							}
-						}
 
+						}
 					}
 					else
-					/* the TAG process is particular */
 					{
-						if(ope->tags != NULL)
+						pos = ui_repdist_result_get_pos(tmpfor, data->filter->mindate, ope);
+						if( pos == active )
 						{
-						guint32 *tptr = ope->tags;
 
-							while(*tptr)
-							{
-								pos = *tptr - 1;
-
-								DB( g_print(" -> storing tag %d %.2f\n", pos, ope->amount) );
-
-								if( pos == active )
-								{
-									gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-							 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-										LST_DSPOPE_DATAS, ope,
-										-1);
-
-								}
-
-								tptr++;
-							}
+							gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+					 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+								LST_DSPOPE_DATAS, ope,
+								-1);
 
 						}
 					}
 
-
-
 				}
+				else
+				/* the TAG process is particular */
+				{
+					if(ope->tags != NULL)
+					{
+					guint32 *tptr = ope->tags;
+
+						while(*tptr)
+						{
+							pos = *tptr - 1;
+
+							DB( g_print(" -> storing tag %d %.2f\n", pos, ope->amount) );
+
+							if( pos == active )
+							{
+								gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+						 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+									LST_DSPOPE_DATAS, ope,
+									-1);
+
+							}
+
+							tptr++;
+						}
+
+					}
+				}
+
+
+
 			}
-next1:
+
 			list = g_list_next(list);
 		}
 
@@ -679,9 +668,9 @@ struct ui_repdist_data *data;
 
 	//minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
 
-	hb_label_set_colvalue(GTK_LABEL(data->TX_total[0]), data->total_expense, GLOBALS->minor);
-	hb_label_set_colvalue(GTK_LABEL(data->TX_total[1]), data->total_income, GLOBALS->minor);
-	hb_label_set_colvalue(GTK_LABEL(data->TX_total[2]), data->total_expense + data->total_income, GLOBALS->minor);
+	hb_label_set_colvalue(GTK_LABEL(data->TX_total[0]), data->total_expense, GLOBALS->kcur, GLOBALS->minor);
+	hb_label_set_colvalue(GTK_LABEL(data->TX_total[1]), data->total_income, GLOBALS->kcur, GLOBALS->minor);
+	hb_label_set_colvalue(GTK_LABEL(data->TX_total[2]), data->total_expense + data->total_income, GLOBALS->kcur, GLOBALS->minor);
 
 
 }
@@ -782,6 +771,12 @@ gdouble exprate, incrate, balrate;
 	to   = data->filter->maxdate;
 	if(to < from) return;
 
+
+	g_queue_free (data->txn_queue);
+	data->txn_queue = hbfile_transaction_get_partial(data->filter->mindate, data->filter->maxdate);
+	
+	DB( g_print(" nb-txn=%d\n", g_queue_get_length (data->txn_queue) ) );
+
 	/* count number or results */
 	switch(tmpfor)
 	{
@@ -827,38 +822,65 @@ gdouble exprate, incrate, balrate;
 
 	if(tmp_expense && tmp_income)
 	{
+
+		DB( g_print(" - ok memory\n") );
+
 		/* compute the results */
-		list = g_list_first(GLOBALS->ope_list);
+		list = g_queue_peek_head_link(data->txn_queue);
 		while (list != NULL)
 		{
 		Transaction *ope = list->data;
-		Account *acc;
-			//debug
-			//DB( g_print("** testing '%s', cat=%d==> %d\n", ope->wording, ope->category, filter_test(data->filter, ope)) );
-			acc = da_acc_get(ope->kacc);
-			if(acc == NULL) goto next1;
-			if((acc->flags & (AF_CLOSED|AF_NOREPORT))) goto next1;
+			
+			DB( g_print("** testing '%s', cat=%d==> %d\n", ope->wording, ope->kcat, filter_test(data->filter, ope)) );
 
-			if( !(ope->status == TXN_STATUS_REMIND) )
+			if( (filter_test(data->filter, ope) == 1) )
 			{
-				if( (filter_test(data->filter, ope) == 1) )
+			guint32 pos = 0;
+			gdouble trn_amount;
+
+				DB( g_print(" - should insert\n") );
+
+				//trn_amount = ope->amount;
+				trn_amount = hb_amount_base(ope->amount, ope->kcur);
+
+				//#1562372 in case of a split we need to take amount for filter categories only
+				if( ope->flags & OF_SPLIT )
 				{
-				guint32 pos = 0;
-				gdouble trn_amount;
+				guint nbsplit = da_splits_count(ope->splits);
+				Split *split;
+				Category *catentry;
+				gint sinsert;
 
-					//trn_amount = to_base_amount(ope->amount, acc->kcur);
-					trn_amount = ope->amount;
+					trn_amount = 0.0;
 
-					//#1562372 in case of a split we need to take amount for filter categories only
-					if( ope->flags & OF_SPLIT )
+					for(i=0;i<nbsplit;i++)
 					{
-					guint nbsplit = da_transaction_splits_count(ope);
+						split = ope->splits[i];
+						catentry = da_cat_get(split->kcat);
+						if(catentry == NULL) continue;
+						sinsert = ( catentry->filter == TRUE ) ? 1 : 0;
+						if(data->filter->option[FILTER_CATEGORY] == 2) sinsert ^= 1;
+
+						DB( g_print(" split '%s' insert=%d\n",catentry->name, sinsert) );
+
+						if( (data->filter->option[FILTER_CATEGORY] == 0) || sinsert)
+						{
+							trn_amount += hb_amount_base(split->amount, ope->kcur);
+						}
+					}
+
+				}
+
+
+				if( tmpfor != BY_REPDIST_TAG )
+				{
+					if( (tmpfor == BY_REPDIST_CATEGORY || tmpfor == BY_REPDIST_SUBCATEGORY) && ope->flags & OF_SPLIT )
+					{
+					guint nbsplit = da_splits_count(ope->splits);
 					Split *split;
 					Category *catentry;
 					gint sinsert;
 
-						trn_amount = 0.0;
-
 						for(i=0;i<nbsplit;i++)
 						{
 							split = ope->splits[i];
@@ -868,127 +890,99 @@ gdouble exprate, incrate, balrate;
 							if(data->filter->option[FILTER_CATEGORY] == 2) sinsert ^= 1;
 
 							DB( g_print(" split '%s' insert=%d\n",catentry->name, sinsert) );
-
+							
 							if( (data->filter->option[FILTER_CATEGORY] == 0) || sinsert)
 							{
-								trn_amount += split->amount;
-							}
-						}
-
-					}
-
-					if( tmpfor != BY_REPDIST_TAG )
-					{
-						if( (tmpfor == BY_REPDIST_CATEGORY || tmpfor == BY_REPDIST_SUBCATEGORY) && ope->flags & OF_SPLIT )
-						{
-						guint nbsplit = da_transaction_splits_count(ope);
-						Split *split;
-						Category *catentry;
-						gint sinsert;
-
-							for(i=0;i<nbsplit;i++)
-							{
-								split = ope->splits[i];
-								catentry = da_cat_get(split->kcat);
-								if(catentry == NULL) continue;
-								sinsert = ( catentry->filter == TRUE ) ? 1 : 0;
-								if(data->filter->option[FILTER_CATEGORY] == 2) sinsert ^= 1;
-
-								DB( g_print(" split '%s' insert=%d\n",catentry->name, sinsert) );
-								
-								if( (data->filter->option[FILTER_CATEGORY] == 0) || sinsert)
+								switch(tmpfor)
 								{
-									switch(tmpfor)
-									{
-										case BY_REPDIST_CATEGORY:
-											{
-												pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
-											}
-											break;
-										case BY_REPDIST_SUBCATEGORY:
-											pos = split->kcat;
-											break;
-									}
-
-									//trn_amount = to_base_amount(split->amount, acc->kcur);
-									trn_amount = split->amount;
-
-									if(trn_amount > 0.0)
-									{
-										tmp_income[pos] += trn_amount;
-										data->total_income  += trn_amount;
-									}
-									else
-									{
-										tmp_expense[pos] += trn_amount;
-										data->total_expense += trn_amount;
-									}
-
+									case BY_REPDIST_CATEGORY:
+										{
+											pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
+										}
+										break;
+									case BY_REPDIST_SUBCATEGORY:
+										pos = split->kcat;
+										break;
 								}
-								// end insert
 
-							}
-						}
-						else
-						{
-							pos = ui_repdist_result_get_pos(tmpfor, from, ope);
-							if(trn_amount > 0.0)
-							{
-								tmp_income[pos] += trn_amount;
-								data->total_income  += trn_amount;
-							}
-							else
-							{
-								tmp_expense[pos] += trn_amount;
-								data->total_expense += trn_amount;
-							}
-						}
-					}
-					else
-					/* the TAG process is particular */
-					{
-						if(ope->tags != NULL)
-						{
-						guint32 *tptr = ope->tags;
-
-							while(*tptr)
-							{
-								pos = *tptr - 1;
-
-								DB( g_print(" -> storing tag %d %s %.2f\n", pos, da_tag_get(*tptr)->name, trn_amount) );
+								trn_amount = hb_amount_base(split->amount, ope->kcur);
+								//trn_amount = split->amount;
 
 								if(trn_amount > 0.0)
 								{
 									tmp_income[pos] += trn_amount;
+									data->total_income  += trn_amount;
 								}
 								else
 								{
 									tmp_expense[pos] += trn_amount;
+									data->total_expense += trn_amount;
 								}
-								tptr++;
-							}
 
-							//#1195859
-							if(trn_amount > 0.0)
-							{
-								data->total_income  += trn_amount;
-							}
-							else
-							{
-								data->total_expense += trn_amount;
 							}
+							// end insert
 
 						}
 					}
-
-					// fix total according to selection
-					//if(tmpkind==0 && !tmp_expense[pos]) { data->total_income  -= ope->amount; }
-					//if(tmpkind==1 && !tmp_income[pos] ) { data->total_expense -= ope->amount; }
-
-
+					else
+					{
+						pos = ui_repdist_result_get_pos(tmpfor, from, ope);
+						if(trn_amount > 0.0)
+						{
+							tmp_income[pos] += trn_amount;
+							data->total_income  += trn_amount;
+						}
+						else
+						{
+							tmp_expense[pos] += trn_amount;
+							data->total_expense += trn_amount;
+						}
+					}
 				}
+				else
+				/* the TAG process is particularly */
+				{
+					if(ope->tags != NULL)
+					{
+					guint32 *tptr = ope->tags;
+
+						while(*tptr)
+						{
+							pos = *tptr - 1;
+
+							DB( g_print(" -> storing tag %d %s %.2f\n", pos, da_tag_get(*tptr)->name, trn_amount) );
+
+							if(trn_amount > 0.0)
+							{
+								tmp_income[pos] += trn_amount;
+							}
+							else
+							{
+								tmp_expense[pos] += trn_amount;
+							}
+							tptr++;
+						}
+
+						//#1195859
+						if(trn_amount > 0.0)
+						{
+							data->total_income  += trn_amount;
+						}
+						else
+						{
+							data->total_expense += trn_amount;
+						}
+
+					}
+				}
+
+				// fix total according to selection
+				//if(tmpkind==0 && !tmp_expense[pos]) { data->total_income  -= ope->amount; }
+				//if(tmpkind==1 && !tmp_income[pos] ) { data->total_expense -= ope->amount; }
+
+
 			}
-next1:
+
 			list = g_list_next(list);
 		}
 
@@ -1364,6 +1358,8 @@ static void ui_repdist_setup(struct ui_repdist_data *data)
 {
 	DB( g_print("\n[repdist] setup\n") );
 
+	data->txn_queue = g_queue_new ();
+
 	data->filter = da_filter_malloc();
 	filter_default_all_set(data->filter);
 
@@ -1427,6 +1423,8 @@ struct WinGeometry *wg;
 
 	DB( g_print("\n[repdist] dispose\n") );
 
+	g_queue_free (data->txn_queue);
+
 	da_filter_free(data->filter);
 
 	g_free(data);
@@ -1523,7 +1521,7 @@ GError *error = NULL;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
 	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("_Minor currency"));
+	widget = gtk_check_button_new_with_mnemonic (_("Euro _minor"));
 	data->CM_minor = widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
@@ -1694,7 +1692,7 @@ GError *error = NULL;
 	widget = gtk_chart_new(CHART_TYPE_COL);
 	data->RE_chart = widget;
 	gtk_chart_set_minor_prefs(GTK_CHART(widget), PREFS->euro_value, PREFS->minor_cur.symbol);
-	//gtk_chart_set_currency(GTK_CHART(widget), GLOBALS->kcur);
+	gtk_chart_set_currency(GTK_CHART(widget), GLOBALS->kcur);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), widget, NULL);
 
 	//todo: setup should move this
@@ -1818,8 +1816,7 @@ gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 
 	if( value )
 	{
-		mystrfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->minor);
-		//hb_strfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->kcur);
+		hb_strfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, value, GLOBALS->kcur, GLOBALS->minor);
 
 		color = get_normal_color_amount(value);
 
@@ -1899,7 +1896,7 @@ GtkTreeViewColumn  *column;
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), PREFS->rules_hint);
+	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (view), PREFS->grid_lines);
 
 	/* column: Name */
 	column = gtk_tree_view_column_new();
