@@ -20,6 +20,17 @@
 #ifndef __HB_ARCHIVE_GTK_H__
 #define __HB_ARCHIVE_GTK_H__
 
+
+enum
+{
+	ARC_TYPE_ALL = 0,
+	ARC_TYPE_SCHEDULED,
+	ARC_TYPE_TEMPLATE
+};
+
+#define LST_DEFARC_SORT_MEMO  1
+#define LST_DEFARC_SORT_PAYEE 2
+
 enum {
 	HID_ARC_MEMO,
 	HID_ARC_VALID,
@@ -38,17 +49,16 @@ struct ui_arc_manage_data
 	Archive		*lastarcitem;
 
 
+	GtkWidget	*RA_type;
 	GtkWidget	*LV_arc;
 
 	GtkWidget   *GR_txnleft;
 	GtkWidget	*PO_pay;
 	GtkWidget	*ST_word;
-	GtkWidget	*ST_amount;	//, *BT_split;
+	GtkWidget	*ST_amount, *BT_split;
 	GtkWidget	*GR_cheque;
 	GtkWidget	*CM_cheque;
-	GtkWidget   *CY_status;
-
-	GtkWidget   *GR_txnright;
+	GtkWidget   *RA_status;
 	GtkWidget	*NU_mode;
 	GtkWidget	*PO_grp;
 	GtkWidget	*PO_acc;
@@ -74,4 +84,4 @@ struct ui_arc_manage_data
 
 GtkWidget *ui_arc_manage_dialog (Archive *ext_arc);
 
-#endif
\ No newline at end of file
+#endif
