@@ -58,15 +58,26 @@ struct ui_asg_manage_data
 	GtkWidget	*BT_add, *BT_rem;
 
 	GtkWidget   *GR_condition;
-	GtkWidget   *GR_assignment;
 	GtkWidget   *CY_field;
 	GtkWidget	*ST_text;
 	GtkWidget	*CM_exact;
-	
-	GtkWidget	*CM_pay, *PO_pay;
-	GtkWidget	*CM_cat, *PO_cat;
+	GtkWidget	*CM_re;
 
+	GtkWidget   *GR_assignment;
+	GtkWidget   *GR_pay;
+	GtkWidget	*RA_pay;
+	GtkWidget   *LB_pay;
+	GtkWidget   *PO_pay;
 
+	GtkWidget   *GR_cat;
+	GtkWidget	*RA_cat;
+	GtkWidget   *LB_cat;
+	GtkWidget	*PO_cat;
+
+	GtkWidget   *GR_mod;
+	GtkWidget	*RA_mod;
+	GtkWidget   *LB_mod;
+	GtkWidget	*NU_mod;
 };
 
 
