@@ -248,6 +248,57 @@ GtkTreeViewColumn	*column;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
+//old stuf for transition waiting import rewrite
+static void da_obsolete_transaction_destroy(GList *list)
+{
+GList *tmplist = g_list_first(list);
+
+	while (tmplist != NULL)
+	{
+	Transaction *item = tmplist->data;
+		da_transaction_free(item);
+		tmplist = g_list_next(tmplist);
+	}
+	g_list_free(list);
+}
+
+static GQueue *da_obsolete_transaction_get_partial(guint32 minjulian)
+{
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
+GQueue *txn_queue;
+
+	txn_queue = g_queue_new ();
+
+	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+	lnk_acc = g_list_first(lst_acc);
+	while (lnk_acc != NULL)
+	{
+	Account *acc = lnk_acc->data;
+
+		lnk_txn = g_queue_peek_tail_link(acc->txn_queue);
+		while (lnk_txn != NULL)
+		{
+		Transaction *txn = lnk_txn->data;
+
+			if( txn->date < minjulian ) //no need to go below mindate
+				break;
+
+			g_queue_push_head (txn_queue, txn);
+			
+			lnk_txn = g_list_previous(lnk_txn);
+		}
+	
+		lnk_acc = g_list_next(lnk_acc);
+	}
+	g_list_free(lst_acc);
+
+	return txn_queue;
+}
+
+
+
+
 /* count account to be imported */
 static void _import_context_count(struct import_data *data)
 {
@@ -287,7 +338,7 @@ static void _import_context_clear(ImportContext *ictx)
 	DB( g_print("\n[import] context clear\n") );
 
 	if(ictx->trans_list)
-		da_transaction_destroy(ictx->trans_list);
+		da_obsolete_transaction_destroy(ictx->trans_list);
 	ictx->trans_list  = NULL;
 	ictx->next_acc_key = da_acc_length();
 	ictx->datefmt  = PREFS->dtex_datefmt;
@@ -488,7 +539,11 @@ guint maxgap;
 			implist = g_list_next(implist);
 		}
 		
-		tmplist = g_list_first(GLOBALS->ope_list);
+		
+		GQueue *txn_queue = da_obsolete_transaction_get_partial(mindate);
+
+		//tmplist = g_list_first(GLOBALS->ope_list);
+		tmplist = g_queue_peek_head_link(txn_queue);
 		while (tmplist != NULL)
 		{
 		Transaction *ope = tmplist->data;
@@ -516,6 +571,9 @@ guint maxgap;
 
 			tmplist = g_list_next(tmplist);
 		}
+		
+		g_queue_free (txn_queue);
+		
 	}
 
 	DB( g_print(" nb_duplicate = %d\n", ictx->nb_duplicate) );
@@ -1229,11 +1287,6 @@ struct import_data *data;
 }
 
 
-
-
-
-
-
 static void _import_tryload_file(struct import_data *data)
 {
 ImportContext *ictx = &data->ictx;
@@ -1285,21 +1338,35 @@ ImportContext *ictx = &data->ictx;
 
 		for(i=0;i<NUM_PRF_DATEFMT;i++)
 		{
+		gboolean do_fix;
+
 			if(i != PREFS->dtex_datefmt)	//don't reload with user pref date format
 			{
-				DB( g_print(" fail, reload with '%s'\n", CYA_IMPORT_DATEORDER[i]) );
-				//#1448549
-				import_clearall(data);
-				ictx->encoding = encoding; //#1425986 keep encoding with us
-				ictx->datefmt = i;
-				_import_tryload_file(data);
+				do_fix = ui_dialog_msg_question(
+					GTK_WINDOW(data->assistant),
+					_("Some date convertion failed"),
+					_("Reload using date order: '%s' ?"),
+					CYA_IMPORT_DATEORDER[i]
+					);
 
-				DB( g_print(" -> reloaded: nbtrans=%d, date errors=%d\n", ictx->cnt_new_ope, ictx->cnt_err_date) );
+				if(do_fix == GTK_RESPONSE_YES)
+				{	
+					DB( g_print(" fail, reload with '%s'\n", CYA_IMPORT_DATEORDER[i]) );
+					//#1448549
+					import_clearall(data);
+					ictx->encoding = encoding; //#1425986 keep encoding with us
+					ictx->datefmt = i;
+					_import_tryload_file(data);
+
+					DB( g_print(" -> reloaded: nbtrans=%d, date errors=%d\n", ictx->cnt_new_ope, ictx->cnt_err_date) );
+
+					if(ictx->cnt_err_date == 0)
+						break;
+				}
 
-				if(ictx->cnt_err_date == 0)
-					break;
 			}
 		}
+		
 	}
 
 	DB( g_print(" end of try import\n") );
@@ -1922,7 +1989,6 @@ gint crow, row;
 	gtk_container_add (GTK_CONTAINER (scrollwin), widget);
 	gtk_grid_attach (GTK_GRID (group_grid), scrollwin, 0, row, 2, 1);
 
-	row++;
 	expander = gtk_expander_new (_("Detail of existing transaction (possible duplicate)"));
 	data->GR_duplicate = expander;
 	gtk_grid_attach (GTK_GRID (group_grid), expander, 0, crow++, 2, 1);
@@ -2079,8 +2145,7 @@ GtkWidget *ui_import_assistant_new (gint filetype)
 {
 struct import_data *data;
 GtkWidget *assistant;
-gint w, h;
-gint pos;
+gint w, h, pos;
 
 	data = g_malloc0(sizeof(struct import_data));
 	if(!data) return NULL;
@@ -2103,7 +2168,6 @@ gint pos;
 	gtk_window_set_default_size (GTK_WINDOW(assistant), w*0.8, h*0.8);
 
 
-
 	pos = 0;
 	data->pages[pos++] = ui_import_panel_welcome_create (assistant, data);
 	data->pages[pos++] = ui_import_panel_filechooser_create (assistant, data);
