@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -233,11 +233,20 @@ GtkTreeViewColumn  *column;
 	g_object_unref(store);
 
 	/* column 1 */
-	column = gtk_tree_view_column_new();
 	renderer = gtk_cell_renderer_text_new ();
+	g_object_set(renderer, 
+		"ellipsize", PANGO_ELLIPSIZE_END,
+	    "ellipsize-set", TRUE,
+	    NULL);	
+
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Category"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, ui_bud_listview_cell_data_function_text, GINT_TO_POINTER(1), NULL);
+	gtk_tree_view_column_set_alignment (column, 0.5);
+	gtk_tree_view_column_set_min_width(column, HB_MINWIDTH_LIST);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DEFACC_NAME);
+	gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* icon column */
@@ -252,7 +261,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_set_search_equal_func(GTK_TREE_VIEW(treeview), ui_bud_listview_search_equal_func, NULL, NULL);
 
 	
-	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(treeview), FALSE);
+	//gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(treeview), FALSE);
 	//gtk_tree_view_set_reorderable (GTK_TREE_VIEW(treeview), TRUE);
 
 	return(treeview);
@@ -497,7 +506,7 @@ const gchar *encoding;
 			{
 				ui_dialog_msg_infoerror(GTK_WINDOW(data->window), GTK_MESSAGE_ERROR,
 					_("File format error"),
-					_("The csv file must contains the exact numbers of column,\nseparated by a semi-colon, read the help for more details.")
+					_("The CSV file must contains the exact numbers of column,\nseparated by a semi-colon, please see the help for more details.")
 					);
 			}
 
@@ -971,7 +980,7 @@ GtkWidget *ui_bud_manage_dialog (void)
 {
 struct ui_bud_manage_data data;
 GtkWidget *dialog, *content_area;
-GtkWidget *content_grid, *group_grid, *scrollwin, *label;
+GtkWidget *content_grid, *group_grid, *table, *scrollwin, *label;
 GtkWidget *treeview, *hpaned, *bbox, *vbox, *hbox;
 GtkWidget *menu, *menuitem, *widget, *image, *tbar;
 GtkToolItem *toolitem;
@@ -1004,14 +1013,60 @@ gint crow, row;
 	//window contents
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));	 	// return a vbox
 
+  //our table
+	table = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_MEDIUM);
+	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_MEDIUM);
+	g_object_set(table, "margin", SPACING_MEDIUM, NULL);
+	gtk_box_pack_start (GTK_BOX (content_area), table, TRUE, TRUE, 0);
+
+	crow = 0;
+	bbox = make_radio(CYA_CAT_TYPE, TRUE, GTK_ORIENTATION_HORIZONTAL);
+	data.RA_type = bbox;
+	gtk_widget_set_halign (bbox, GTK_ALIGN_CENTER);
+	gtk_grid_attach (GTK_GRID (table), bbox, 0, crow, 1, 1);
+
+	widget = radio_get_nth_widget(GTK_CONTAINER(bbox), 1);
+	if(widget)
+		g_signal_connect (widget, "toggled", G_CALLBACK (ui_bud_manage_type_changed_cb), &data);
+
+	menu = gtk_menu_new ();
+	gtk_widget_set_halign (menu, GTK_ALIGN_END);
+
+	menuitem = gtk_menu_item_new_with_mnemonic (_("_Import CSV"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_bud_manage_load_csv), &data);
+
+	menuitem = gtk_menu_item_new_with_mnemonic (_("E_xport CSV"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_bud_manage_save_csv), &data);
+	
+	gtk_widget_show_all (menu);
+	
+	widget = gtk_menu_button_new();
+	image = gtk_image_new_from_icon_name (ICONNAME_HB_BUTTON_MENU, GTK_ICON_SIZE_MENU);
+
+	//gchar *thename;
+	//gtk_image_get_icon_name(image, &thename, NULL);
+	//g_print("the name is %s\n", thename);
+
+	g_object_set (widget, "image", image, "popup", GTK_MENU(menu),  NULL);
+
+	gtk_widget_set_hexpand (widget, FALSE);
+	gtk_widget_set_halign (widget, GTK_ALIGN_END);
+	gtk_grid_attach (GTK_GRID (table), widget, 0, crow++, 1, 1);
+
+
+
+	crow++;
 	hpaned = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
-	gtk_container_set_border_width (GTK_CONTAINER(hpaned), SPACING_MEDIUM);
-	gtk_container_add(GTK_CONTAINER(content_area), hpaned);
+	//gtk_container_set_border_width (GTK_CONTAINER(hpaned), SPACING_MEDIUM);
+	gtk_grid_attach (GTK_GRID (table), hpaned, 0, crow++, 1, 1);
 
 	/* left area */
 	//list
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	gtk_widget_set_margin_end(vbox, SPACING_SMALL);
+	gtk_widget_set_margin_right(vbox, SPACING_SMALL);
 	gtk_paned_pack1 (GTK_PANED(hpaned), vbox, TRUE, FALSE);
 	
 	scrollwin = gtk_scrolled_window_new(NULL,NULL);
@@ -1020,7 +1075,6 @@ gint crow, row;
  	treeview = (GtkWidget *)ui_bud_listview_new();
  	data.LV_cat = treeview;
 	gtk_widget_set_size_request(treeview, HB_MINWIDTH_LIST, -1);
-	//gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), PREFS->rules_hint);
 	gtk_container_add(GTK_CONTAINER(scrollwin), treeview);
 	gtk_box_pack_start (GTK_BOX(vbox), scrollwin, TRUE, TRUE, 0);
 
@@ -1056,44 +1110,10 @@ gint crow, row;
 	gtk_grid_set_row_spacing (GTK_GRID (content_grid), SPACING_LARGE);
 	gtk_orientable_set_orientation(GTK_ORIENTABLE(content_grid), GTK_ORIENTATION_VERTICAL);
 	//gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_MEDIUM);
-	gtk_widget_set_margin_start(content_grid, SPACING_SMALL);
+	gtk_widget_set_margin_left(content_grid, SPACING_SMALL);
 	gtk_paned_pack2 (GTK_PANED(hpaned), content_grid, FALSE, FALSE);
 
 	crow = 0;
-	bbox = make_radio(CYA_CAT_TYPE, TRUE, GTK_ORIENTATION_HORIZONTAL);
-	data.RA_type = bbox;
-	gtk_widget_set_halign (bbox, GTK_ALIGN_CENTER);
-	gtk_grid_attach (GTK_GRID (content_grid), bbox, 0, crow, 3, 1);
-
-	widget = radio_get_nth_widget(GTK_CONTAINER(bbox), 1);
-	if(widget)
-		g_signal_connect (widget, "toggled", G_CALLBACK (ui_bud_manage_type_changed_cb), &data);
-
-	menu = gtk_menu_new ();
-	gtk_widget_set_halign (menu, GTK_ALIGN_END);
-
-	menuitem = gtk_menu_item_new_with_mnemonic (_("_Import CSV"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_bud_manage_load_csv), &data);
-
-	menuitem = gtk_menu_item_new_with_mnemonic (_("E_xport CSV"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_bud_manage_save_csv), &data);
-	
-	gtk_widget_show_all (menu);
-	
-	widget = gtk_menu_button_new();
-	image = gtk_image_new_from_icon_name (ICONNAME_HB_BUTTON_MENU, GTK_ICON_SIZE_MENU);
-
-	//gchar *thename;
-	//gtk_image_get_icon_name(image, &thename, NULL);
-	//g_print("the name is %s\n", thename);
-
-	g_object_set (widget, "image", image, "popup", GTK_MENU(menu),  NULL);
-
-	gtk_widget_set_hexpand (widget, FALSE);
-	gtk_widget_set_halign (widget, GTK_ALIGN_END);
-	gtk_grid_attach (GTK_GRID (content_grid), widget, 0, crow++, 1, 1);
 
 	
 	// group :: General
@@ -1113,8 +1133,6 @@ gint crow, row;
  	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 4, 1);
 
 	row++;
-    //label = make_label(_("Each"), 1.0, 0.5);
-	//gtk_grid_attach (GTK_GRID (group_grid), label, 1, 2, row, row+1);
 	widget = make_amount(label);
 	data.spinner[0] = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
@@ -1148,7 +1166,7 @@ gint crow, row;
 		l = ((i<6) ? 1 : 3);
 		t = row + ((i<6) ? i : i-6);
 
-		label = make_label(months[i], 0, 0.5);
+		label = make_label_widget(months[i]);
 		data.label[i+1] = label;
 		gtk_grid_attach (GTK_GRID (group_grid), label, l, t, 1, 1);
 
