@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -22,6 +22,9 @@
 #include "ui-dialogs.h"
 #include "list_operation.h"
 
+#include "hb-currency.h"
+#include "ui-currency.h"
+
 
 /* = = = = = = = = = = */
 /* = = = = = = = = = = = = = = = = = = = = */
@@ -201,7 +204,7 @@ gint crow, row, count;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("Account"), 0, 0.5);
+	label = make_label_widget(_("Account"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_label(NULL, 1.0, 0.5);
 	count = da_acc_length ();
@@ -210,16 +213,16 @@ gint crow, row, count;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("Transaction"), 0, 0.5);
+	label = make_label_widget(_("Transaction"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_label(NULL, 1.0, 0.5);
-	count = g_list_length(GLOBALS->ope_list);
+	count = da_transaction_length();
 	ui_label_set_integer(GTK_LABEL(widget), count);
 	gtk_widget_set_hexpand(widget, TRUE);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("Payee"), 0, 0.5);
+	label = make_label_widget(_("Payee"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_label(NULL, 1.0, 0.5);
 	count = da_pay_length ();
@@ -228,7 +231,7 @@ gint crow, row, count;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("Category"), 0, 0.5);
+	label = make_label_widget(_("Category"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_label(NULL, 1.0, 0.5);
 	count = da_cat_length ();
@@ -237,7 +240,7 @@ gint crow, row, count;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("Assignment"), 0, 0.5);
+	label = make_label_widget(_("Assignment"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_label(NULL, 1.0, 0.5);
 	count = da_asg_length ();
@@ -263,6 +266,148 @@ gint crow, row, count;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
+struct dialog_currency_data
+{
+	GtkWidget   *window;
+	GtkWidget   *LB_currency;
+	GtkWidget   *BT_change;
+	Currency4217 *curfmt;
+};
+
+static void ui_dialog_upgrade_choose_currency_change_action(GtkWidget *widget, gpointer user_data)
+{
+struct dialog_currency_data *data = user_data;
+Currency4217 *curfmt;
+
+	data->curfmt = NULL;
+
+	curfmt = ui_cur_select_dialog_new(GTK_WINDOW(data->window), CUR_SELECT_MODE_BASE);
+	if( curfmt != NULL )
+	{
+	gchar label[128];
+	gchar *name;
+		
+		DB( g_printf("- user selected: '%s' '%s'\n", curfmt->curr_iso_code, curfmt->name) );
+
+		data->curfmt = curfmt;
+
+		name = curfmt->name;
+
+		g_snprintf(label, 127, "%s - %s", curfmt->curr_iso_code, name);
+		gtk_label_set_text (GTK_LABEL(data->LB_currency), label);
+	}
+}
+
+
+static void ui_dialog_upgrade_choose_currency_fill(struct dialog_currency_data *data)
+{
+Currency *cur;
+gchar label[128];
+
+	data->curfmt = NULL;
+
+	cur = da_cur_get (GLOBALS->kcur);
+
+	g_snprintf(label, 127, "%s - %s", cur->iso_code, cur->name);
+	gtk_label_set_text (GTK_LABEL(data->LB_currency), label);
+}
+
+
+
+void ui_dialog_upgrade_choose_currency(void)
+{
+struct dialog_currency_data data;
+GtkWidget *dialog, *content_area, *content_grid, *group_grid;
+GtkWidget *label, *widget;
+gint crow, row;
+
+	dialog = gtk_dialog_new_with_buttons (_("Upgrade"),
+		GTK_WINDOW (GLOBALS->mainwindow),
+		0,
+		_("_Cancel"), GTK_RESPONSE_CANCEL,
+		_("_OK"), GTK_RESPONSE_ACCEPT,
+		NULL);
+
+	data.window = dialog;
+
+	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
+
+	content_grid = gtk_grid_new();
+	gtk_grid_set_row_spacing (GTK_GRID (content_grid), SPACING_LARGE);
+	gtk_orientable_set_orientation(GTK_ORIENTABLE(content_grid), GTK_ORIENTATION_VERTICAL);
+	gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_MEDIUM);
+	gtk_box_pack_start (GTK_BOX (content_area), content_grid, TRUE, TRUE, 0);
+
+	crow = 0;
+	// group :: file title
+    group_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
+
+	row = 0;
+	label = make_label(_("Select a base currency"), 0, 0);
+	gimp_label_set_attributes(GTK_LABEL(label), 
+		PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, 
+		PANGO_ATTR_SCALE,  PANGO_SCALE_LARGE, 
+		-1);
+	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 3, 1);
+
+	row++;
+	label = make_label(
+		_("Starting v5.1, HomeBank can manage several currencies\n" \
+		  "if the currency below is not correct, please change it:"), 0, 0);
+	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 3, 1);
+
+	row++;
+	label = make_label_widget(_("Currency:"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+	widget = make_label (NULL, 0, 0.5);
+	data.LB_currency = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+	widget = gtk_button_new_with_mnemonic (_("_Change"));
+	data.BT_change = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+	g_signal_connect (G_OBJECT (data.BT_change), "clicked", G_CALLBACK (ui_dialog_upgrade_choose_currency_change_action), &data);
+
+
+	ui_dialog_upgrade_choose_currency_fill(&data);
+
+	gtk_widget_show_all(content_grid);
+
+	//wait for the user
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if(result == GTK_RESPONSE_ACCEPT)
+	{
+
+		if( data.curfmt != NULL )
+		{
+			hbfile_replace_basecurrency(data.curfmt);
+		}
+	}
+
+	// in any case set every accounts to base currency
+	GList *list;
+	list = g_hash_table_get_values(GLOBALS->h_acc);
+	while (list != NULL)
+	{
+	Account *acc = list->data;
+
+		account_set_currency(acc, GLOBALS->kcur);
+		list = g_list_next(list);
+	}
+	g_list_free(list);
+	
+	// cleanup and destroy
+	gtk_widget_destroy (dialog);
+
+}
+
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
 
 
 
@@ -389,12 +534,12 @@ gboolean retval;
 
 	if( action == GTK_FILE_CHOOSER_ACTION_OPEN )
 	{
-		title = _("Open homebank file");
+		title = _("Open HomeBank file");
 		button = _("_Open");
 	}
 	else
 	{
-		title = _("Save homebank file as");
+		title = _("Save HomeBank file as");
 		button = _("_Save");
 	}
 
@@ -546,12 +691,13 @@ GtkWidget *dialog = NULL;
 }
 
 
-
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 struct xfer_data
 {
 	GtkWidget   *window;
 	GtkWidget	*radio[2];
+	GtkWidget	*srctreeview;
 	GtkWidget	*treeview;
 };
 
@@ -590,23 +736,23 @@ static void ui_dialog_transaction_xfer_select_child_selection_cb(GtkTreeSelectio
 }
 
 
-Transaction *ui_dialog_transaction_xfer_select_child(GList *matchlist)
+Transaction *ui_dialog_transaction_xfer_select_child(GtkWindow *parentwindow, Transaction *stxn, GList *matchlist)
 {
 struct xfer_data data;
-GtkWidget *window, *content, *mainvbox, *vbox, *sw, *label;
+GtkWidget *window, *content, *mainvbox, *vbox, *sw, *label, *LB_several;
 GtkTreeModel		 *newmodel;
 GtkTreeIter			 newiter;
 Transaction *retval = NULL;
 
-			window = gtk_dialog_new_with_buttons (NULL,
-						    //GTK_WINDOW (parentwindow),
-			    			NULL,
-						    0,
+	window = gtk_dialog_new_with_buttons (
+    			_("Select among possible transactions..."),
+    			GTK_WINDOW (parentwindow),
+			    0,
 			    _("_Cancel"),
-						    GTK_RESPONSE_REJECT,
-						    _("_OK"),
-						    GTK_RESPONSE_ACCEPT,
-						    NULL);
+			    GTK_RESPONSE_REJECT,
+			    _("_OK"),
+			    GTK_RESPONSE_ACCEPT,
+			    NULL);
 
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)&data);
 	data.window = window;
@@ -619,18 +765,19 @@ Transaction *retval = NULL;
 		gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
 		gtk_container_set_border_width (GTK_CONTAINER (mainvbox), SPACING_SMALL);
 
-		gtk_window_set_title (GTK_WINDOW (window), _("Select among possible transactions..."));
+	// source listview
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	//gtk_widget_set_size_request(sw, -1, HB_MINWIDTH_LIST/2);
 
-		label = make_label(_(
-		"HomeBank has found some transaction that may be " \
-		"the associated transaction for the internal transfer."), 0.0, 0.5
-		);
-	gimp_label_set_attributes (GTK_LABEL (label),
-                             PANGO_ATTR_SCALE,  PANGO_SCALE_SMALL,
-                             -1);
-	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, SPACING_SMALL);
+	data.srctreeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_ope_columns);
+	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(data.srctreeview)), GTK_SELECTION_NONE);
+	gtk_container_add (GTK_CONTAINER (sw), data.srctreeview);
+	gtk_box_pack_start (GTK_BOX (mainvbox), sw, TRUE, TRUE, 0);
 
 
+	// actions 
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
 	gtk_box_pack_start (GTK_BOX (mainvbox), vbox, FALSE, TRUE, SPACING_SMALL);
 
@@ -638,34 +785,50 @@ Transaction *retval = NULL;
 	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
-
 	data.radio[0] = gtk_radio_button_new_with_label (NULL, _("create a new transaction"));
 	gtk_box_pack_start (GTK_BOX (vbox), data.radio[0], FALSE, FALSE, 0);
 
 	data.radio[1] = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON (data.radio[0]), _("select an existing transaction"));
 	gtk_box_pack_start (GTK_BOX (vbox), data.radio[1], FALSE, FALSE, 0);
 
+
+	label = make_label(_(
+		"HomeBank has found some transaction that may be " \
+		"the associated transaction for the internal transfer."), 0.0, 0.5
+		);
+	LB_several = label;
+	gimp_label_set_attributes (GTK_LABEL (label),
+                             PANGO_ATTR_SCALE,  PANGO_SCALE_SMALL,
+                             -1);
+	gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, SPACING_SMALL);
+
+	// target listview
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	data.treeview = create_list_transaction(LIST_TXN_TYPE_BOOK, PREFS->lst_ope_columns);
+	data.treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_ope_columns);
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(data.treeview)), GTK_SELECTION_SINGLE);
 	gtk_container_add (GTK_CONTAINER (sw), data.treeview);
 	gtk_box_pack_start (GTK_BOX (mainvbox), sw, TRUE, TRUE, 0);
 
-	g_signal_connect (data.radio[0], "toggled", G_CALLBACK (ui_dialog_transaction_xfer_select_child_cb), NULL);
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data.treeview)), "changed", G_CALLBACK (ui_dialog_transaction_xfer_select_child_selection_cb), NULL);
+	/* populate source */
+	if( stxn != NULL )
+	{
+		newmodel = gtk_tree_view_get_model(GTK_TREE_VIEW(data.srctreeview));
+		gtk_list_store_clear (GTK_LIST_STORE(newmodel));
 	
-	/* populate */
+		gtk_list_store_append (GTK_LIST_STORE(newmodel), &newiter);
+
+		gtk_list_store_set (GTK_LIST_STORE(newmodel), &newiter,
+		LST_DSPOPE_DATAS, stxn,
+		-1);
+	}
+
+	/* populate target */
 	newmodel = gtk_tree_view_get_model(GTK_TREE_VIEW(data.treeview));
-
-
-
-
 	gtk_list_store_clear (GTK_LIST_STORE(newmodel));
 
-
 	GList *tmplist = g_list_first(matchlist);
 	while (tmplist != NULL)
 	{
@@ -683,37 +846,53 @@ Transaction *retval = NULL;
 		tmplist = g_list_next(tmplist);
 	}
 
+
+	g_signal_connect (data.radio[0], "toggled", G_CALLBACK (ui_dialog_transaction_xfer_select_child_cb), NULL);
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data.treeview)), "changed", G_CALLBACK (ui_dialog_transaction_xfer_select_child_selection_cb), NULL);
+
+	gtk_widget_show_all(mainvbox);
+
 	//initialize
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data.radio[1]), TRUE);
+	gtk_widget_set_sensitive (data.radio[1], TRUE);
+	if( g_list_length (matchlist) <= 0 )
+	{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data.radio[0]), TRUE);
+		gtk_widget_set_sensitive (data.radio[1], FALSE);
+		gtk_widget_set_visible (LB_several, FALSE);
+	}
+	else
+	{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data.radio[1]), TRUE);
+		gtk_widget_set_visible (LB_several, TRUE);
+	}
+	
+	ui_dialog_transaction_xfer_select_child_cb(data.radio[0], NULL);
 
+	//wait for the user
+	gint result = gtk_dialog_run (GTK_DIALOG (window));
 
-		gtk_widget_show_all(mainvbox);
+	if(result == GTK_RESPONSE_ACCEPT)
+	{
+	gboolean bnew;
 
-		//wait for the user
-		gint result = gtk_dialog_run (GTK_DIALOG (window));
-
-		if(result == GTK_RESPONSE_ACCEPT)
+		bnew = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data.radio[0]));
+		if( bnew == FALSE )
 		{
-		gboolean bnew;
+		GtkTreeSelection *selection;
+		GtkTreeModel		 *model;
+		GtkTreeIter			 iter;
 
-			bnew = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data.radio[0]));
-			if( bnew == FALSE)
+			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data.treeview));
+			if (gtk_tree_selection_get_selected(selection, &model, &iter))
 			{
-			GtkTreeSelection *selection;
-			GtkTreeModel		 *model;
-			GtkTreeIter			 iter;
-
-				selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data.treeview));
-				if (gtk_tree_selection_get_selected(selection, &model, &iter))
-				{
-					gtk_tree_model_get(model, &iter, LST_DSPOPE_DATAS, &retval, -1);
-				}
+				gtk_tree_model_get(model, &iter, LST_DSPOPE_DATAS, &retval, -1);
 			}
-
 		}
 
-		// cleanup and destroy
-		gtk_widget_destroy (window);
+	}
+
+	// cleanup and destroy
+	gtk_widget_destroy (window);
 
 	return retval;
 }
