@@ -29,7 +29,7 @@ enum
 
 #define LST_DEFPAY_SORT_NAME	 1
 #define LST_DEFPAY_SORT_USED	 2
-
+#define LST_DEFPAY_SORT_DEFCAT   3
 
 struct ui_pay_manage_dialog_data
 {
@@ -51,7 +51,9 @@ struct payPopContext
 	guint	except_key;
 };
 
+/* = = = = = = = = = = */
 
+gchar *ui_pay_comboboxentry_get_name(GtkComboBox *entry_box);
 guint32 ui_pay_comboboxentry_get_key(GtkComboBox *entry_box);
 guint32 ui_pay_comboboxentry_get_key_add_new(GtkComboBox *entry_box);
 Payee *ui_pay_comboboxentry_get(GtkComboBox *entry_box);
