@@ -24,6 +24,8 @@
 #include "dsp_mainwindow.h"
 #include "gtk-chart-colors.h"
 
+#include "ui-currency.h"
+
 
 /****************************************************************************/
 /* Debug macros                                                             */
@@ -100,6 +102,15 @@ N_("Text beside icons"),
 NULL
 };
 
+static gchar *CYA_GRID_LINES[] = {
+N_("None"),
+N_("Horizontal"),
+N_("Vertical"),
+N_("Both"),
+NULL
+};
+
+
 gchar *CYA_TANGO_COLORS[] = {
 "----",
 N_("Tango light"),
@@ -116,8 +127,8 @@ NULL
 };
 
 gchar *CYA_IMPORT_OFXNAME[] = {
-N_("Memo"),
 N_("Payee"),
+N_("Memo"),
 NULL
 };
 
@@ -140,7 +151,7 @@ typedef struct
 	//gchar		*prefix_symbol;		/* max symbol is 3 digits in unicode */
 	//gchar		*suffix_symbol;		/* but mostly is 1 digit */
 	gchar		*symbol;
-	gboolean	is_prefix;
+	gboolean	sym_prefix;
 	gchar		*decimal_char;
 	gchar		*grouping_char;
 	gshort		frac_digits;
@@ -183,14 +194,14 @@ static EuroParams euro_params[] =
 /* 2014 */
 	{ "LVL", "Latvia"        , 0.702804 , "lat.", FALSE, ",", "" , 2  },	// jan. 2014
 /* 2016 */
-	{ "LTL", "Lithuania"     , 3.45280	, "Lt." , TRUE , ",", "" , 2  },	// jan. 2016
+	{ "LTL", "Lithuania"     , 3.45280	, "Lt." , TRUE , ",", "" , 2  },	// jan. 2015
 
 /* future */
 	{ "BGN", "Bulgaria"      , 1.95583	, "лв." , TRUE , ",", " ", 2  },	// non-fixé - 2014 target for euro
 	{ "HUF", "Hungary"       , 261.51	, "Ft"  , TRUE , ",", " ", 2  },	// non-fixé - No current target for euro
-	{ "RON", "Romania"       , 3.5155	, "Leu" , FALSE, ",", ".", 2  },	// non-fixé - 2016 target for euro earliest
-	{ "CZK", "Czech republic", 28.36	, "Kč"  , FALSE, ",", " ", 2  },	// non-fixé - 2016 earliest
-	{ "HRK", "Croatia"       , 1.0000   , "kn"  , FALSE, "" , ".", 0  },	// non-fixé - 2016 target for euro earliest
+	{ "RON", "Romania"       , 3.5155	, "Leu" , FALSE, ",", ".", 2  },	// non-fixé - 2015 target for euro earliest
+	{ "CZK", "Czech republic", 28.36	, "Kč"  , FALSE, ",", " ", 2  },	// non-fixé - 2015 earliest
+	{ "HRK", "Croatia"       , 1.0000   , "kn"  , FALSE, "" , ".", 0  },	// non-fixé - 2015 target for euro earliest
 	{ "PLN", "Poland"        , 0.25     , "zł"  , FALSE, ",", "" , 2  },	// non-fixé - No current target for euro
 
 //	{ "   ", ""    , 1.00000	, ""   , ""  , FALSE, ",", "", 2  },
@@ -674,92 +685,33 @@ GDate *date;
 }
 
 
-/*
-** update the number sample label
-*/
-static void defpref_numberbase_sample(GtkWidget *widget, gpointer user_data)
-{
-struct defpref_data *data;
-struct CurrencyFmt cur;
-gchar formatd_buf[G_ASCII_DTOSTR_BUF_SIZE];
-gchar  buf[128], *ptr;
-
-	DB( g_print("\n[ui-pref] number sample\n") );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-	cur.symbol = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_num_symbol));
-	cur.is_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_num_isprefix));
-	cur.decimal_char  = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_num_decimalchar));
-	cur.grouping_char = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_num_groupingchar));
-	cur.frac_digits   = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_num_fracdigits));
-	g_snprintf(cur.format, 8-1, "%%.%df", cur.frac_digits);
-
-	ptr = cur.monfmt;
-	if(cur.is_prefix)
-	{
-		ptr = g_stpcpy(ptr, cur.symbol);
-		ptr = g_stpcpy(ptr, " ");
-	}
-	ptr = g_stpcpy(ptr, "%s");
-	if(!cur.is_prefix)
-	{
-		ptr = g_stpcpy(ptr, " ");
-		ptr = g_stpcpy(ptr, cur.symbol);
-	}
-	
-	DB( g_print("fmt: %s\n", cur.format) );
-	DB( g_print("monfmt: %s\n", cur.monfmt) );
-
-	g_ascii_formatd(formatd_buf, sizeof (formatd_buf), cur.format, 12345.67);
-	
-	//real_mystrfmon(buf, 127, formatd_buf, &cur);
-	hb_str_formatd(buf, 127, formatd_buf, &cur, TRUE);
-	gtk_label_set_text(GTK_LABEL(data->LB_numberbase), buf);
-
-}
-
 /*
 ** update the number sample label
 */
 static void defpref_numbereuro_sample(GtkWidget *widget, gpointer user_data)
 {
 struct defpref_data *data;
-struct CurrencyFmt cur;
+Currency cur;
 gchar formatd_buf[G_ASCII_DTOSTR_BUF_SIZE];
-gchar  buf[128], *ptr;
+gchar buf[128];
 
 	DB( g_print("\n[ui-pref] number sample\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	cur.symbol = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_euro_symbol));
-	cur.is_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix));
+	cur.sym_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix));
 	cur.decimal_char  = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_euro_decimalchar));
 	cur.grouping_char = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_euro_groupingchar));
 	cur.frac_digits   = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_euro_fracdigits));
-	g_snprintf(cur.format, 8-1, "%%.%df", cur.frac_digits);
-	
-	ptr = cur.monfmt;
-	if(cur.is_prefix)
-	{
-		ptr = g_stpcpy(ptr, cur.symbol);
-		ptr = g_stpcpy(ptr, " ");
-	}
-	ptr = g_stpcpy(ptr, "%s");
-	if(!cur.is_prefix)
-	{
-		ptr = g_stpcpy(ptr, " ");
-		ptr = g_stpcpy(ptr, cur.symbol);
-	}
+
+	da_cur_initformat (&cur);
 	
 	DB( g_print("fmt: %s\n", cur.format) );
-	DB( g_print("monfmt: %s\n", cur.monfmt) );
-	
-	g_ascii_formatd(formatd_buf, sizeof (formatd_buf), cur.format, 12345.67);
-	
-	//real_mystrfmon(buf, 127, formatd_buf, &cur);
+
+	g_ascii_formatd(formatd_buf, sizeof (formatd_buf), cur.format, HB_NUMBER_SAMPLE);
 	hb_str_formatd(buf, 127, formatd_buf, &cur, TRUE);
+
 	gtk_label_set_text(GTK_LABEL(data->LB_numbereuro), buf);
 
 }
@@ -771,27 +723,39 @@ gchar  buf[128], *ptr;
 static void defpref_eurotoggle(GtkWidget *widget, gpointer user_data)
 {
 struct defpref_data *data;
-gboolean bool;
+gboolean sensitive;
 
 	DB( g_print("\n[ui-pref] euro toggle\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_enable));
+	sensitive = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_enable));
+
+	gtk_widget_set_sensitive(data->GRP_currency	 , sensitive);
+	gtk_widget_set_sensitive(data->GRP_rate 	 , sensitive);
+	gtk_widget_set_sensitive(data->GRP_format	 , sensitive);
+}
 
 
+/*
+** set euro value widget from a country
+*/
+static void defpref_eurosetcurrency(GtkWidget *widget, gpointer user_data)
+{
+struct defpref_data *data;
+EuroParams *euro = user_data;
+gchar *buf;
 
-	gtk_widget_set_sensitive(data->CY_euro_preset	, bool);
-	gtk_widget_set_sensitive(data->ST_euro_country	, bool);
-	gtk_widget_set_sensitive(data->NB_euro_value	, bool);
+	
+	DB( g_print("\n[ui-pref] eurosetcurrency\n") );
 
-	gtk_widget_set_sensitive(data->ST_euro_symbol, bool);
-	gtk_widget_set_sensitive(data->CM_euro_isprefix, bool);
-	gtk_widget_set_sensitive(data->ST_euro_decimalchar, bool);
-	gtk_widget_set_sensitive(data->ST_euro_groupingchar, bool);	
-	gtk_widget_set_sensitive(data->NB_euro_fracdigits, bool);
-	gtk_widget_set_sensitive(data->LB_numbereuro, bool);
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+	
+	buf = g_strdup_printf("%s - %s", euro->iso, euro->name);
 
+	gtk_label_set_markup(GTK_LABEL(data->ST_euro_country), buf);
+
+	g_free(buf);
 }
 
 
@@ -809,15 +773,16 @@ gint country;
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	country = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_euro_preset));
+	data->country = country;
 
-	gtk_label_set_text(GTK_LABEL(data->ST_euro_country), euro_params[country].name);
+	defpref_eurosetcurrency(widget, &euro_params[country]);
 
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_euro_value), euro_params[country].value);
 
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_euro_fracdigits), euro_params[country].frac_digits);
 
 	gtk_entry_set_text(GTK_ENTRY(data->ST_euro_symbol)   , euro_params[country].symbol);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix), euro_params[country].is_prefix);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix), euro_params[country].sym_prefix);
 	gtk_entry_set_text(GTK_ENTRY(data->ST_euro_decimalchar) , euro_params[country].decimal_char);
 	gtk_entry_set_text(GTK_ENTRY(data->ST_euro_groupingchar), euro_params[country].grouping_char);
 
@@ -953,7 +918,8 @@ GdkRGBA rgba;
 	gdk_rgba_parse(&rgba, PREFS->color_warn);
 	gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(data->CP_warn_color), &rgba);
 
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_ruleshint), PREFS->rules_hint);
+	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_ruleshint), PREFS->rules_hint);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_gridlines), PREFS->grid_lines);
 
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_fiscyearday), PREFS->fisc_year_day );
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_fiscyearmonth), PREFS->fisc_year_month - 1);
@@ -965,6 +931,7 @@ GdkRGBA rgba;
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_load_last), PREFS->loadlast);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_append_scheduled), PREFS->appendscheduled);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_do_update_currency), PREFS->do_update_currency);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_show_splash), PREFS->showsplash);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_herit_date), PREFS->heritdate);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_hide_reconciled), PREFS->hidereconciled);
@@ -973,15 +940,6 @@ GdkRGBA rgba;
 	/* display */
 	gtk_entry_set_text(GTK_ENTRY(data->ST_datefmt), PREFS->date_format);
 
-	ui_gtk_entry_set_text(data->ST_num_symbol, PREFS->base_cur.symbol);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_num_isprefix), PREFS->base_cur.is_prefix);
-	ui_gtk_entry_set_text(data->ST_num_decimalchar, PREFS->base_cur.decimal_char);
-	ui_gtk_entry_set_text(data->ST_num_groupingchar, PREFS->base_cur.grouping_char);
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_num_fracdigits), PREFS->base_cur.frac_digits);
-
-	//gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_numnbdec), PREFS->num_nbdecimal);
-	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_numseparator), PREFS->num_separator);
-	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_imperial), PREFS->imperial_unit);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_unitismile), PREFS->vehicle_unit_ismile);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_unitisgal), PREFS->vehicle_unit_isgal);
 
@@ -991,19 +949,16 @@ GdkRGBA rgba;
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_daterange_rep), PREFS->date_range_rep);
 
 	/* euro */
-	//defpref_currency_display(data->LB_default, NULL);
-	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_euro_enable), PREFS->euro_active);
 	//gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_euro_preset), PREFS->euro_country);
-	gchar *buf;
-	buf = g_strdup_printf("%s", euro_params[PREFS->euro_country].name);
-	gtk_label_set_markup(GTK_LABEL(data->ST_euro_country), buf);
-	g_free(buf);
+
+	data->country = PREFS->euro_country;
+	defpref_eurosetcurrency(data->window, &euro_params[PREFS->euro_country]);
 
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_euro_value), PREFS->euro_value);
 
 	ui_gtk_entry_set_text(data->ST_euro_symbol, PREFS->minor_cur.symbol);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix), PREFS->minor_cur.is_prefix);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix), PREFS->minor_cur.sym_prefix);
 	ui_gtk_entry_set_text(data->ST_euro_decimalchar, PREFS->minor_cur.decimal_char);
 	ui_gtk_entry_set_text(data->ST_euro_groupingchar, PREFS->minor_cur.grouping_char);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_euro_fracdigits), PREFS->minor_cur.frac_digits);
@@ -1023,10 +978,12 @@ GdkRGBA rgba;
 
 	/* import */
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_dtex_datefmt), PREFS->dtex_datefmt);
+
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_dtex_ofxmemo), PREFS->dtex_ofxmemo);
 
 
 
+
 }
 
 
@@ -1074,7 +1031,8 @@ const gchar *lang;
 	g_free(PREFS->color_warn);
 	PREFS->color_warn = gdk_rgba_to_hex(&rgba);
 
-	PREFS->rules_hint = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_ruleshint));
+	//PREFS->rules_hint = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_ruleshint));
+	PREFS->grid_lines = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_gridlines));
 
 	PREFS->fisc_year_day = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_fiscyearday));
 	PREFS->fisc_year_month = 1 + gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_fiscyearmonth));
@@ -1090,6 +1048,8 @@ const gchar *lang;
 
 	PREFS->loadlast  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_load_last));
 	PREFS->appendscheduled  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_append_scheduled));
+	PREFS->do_update_currency  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_do_update_currency));
+		
 	PREFS->showsplash  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_show_splash));
 	PREFS->heritdate = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_herit_date));
 	PREFS->hidereconciled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_hide_reconciled));
@@ -1101,15 +1061,6 @@ const gchar *lang;
 	g_free(PREFS->date_format);
 	PREFS->date_format = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_datefmt)));
 
-	ui_gtk_entry_replace_text(data->ST_num_symbol, &PREFS->base_cur.symbol);
-	PREFS->base_cur.is_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_num_isprefix));
-	ui_gtk_entry_replace_text(data->ST_num_decimalchar, &PREFS->base_cur.decimal_char);
-	ui_gtk_entry_replace_text(data->ST_num_groupingchar, &PREFS->base_cur.grouping_char);
-	PREFS->base_cur.frac_digits = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_num_fracdigits));
-
-	//PREFS->num_nbdecimal = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_numnbdec));
-	//PREFS->num_separator = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_numseparator));
-	//PREFS->imperial_unit = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_imperial));
 	PREFS->vehicle_unit_ismile = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_unitismile));
 	PREFS->vehicle_unit_isgal = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_unitisgal));
 
@@ -1119,14 +1070,15 @@ const gchar *lang;
 	PREFS->date_range_rep = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_daterange_rep));
 
 	PREFS->euro_active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_enable));
-	PREFS->euro_country = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_euro_preset));
+
+	PREFS->euro_country = data->country;
 	PREFS->euro_value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_euro_value));
 	//strcpy(PREFS->euro_symbol, gtk_entry_get_text(GTK_ENTRY(data->ST_euro_symbol)));
 	//PREFS->euro_nbdec = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_euro_nbdec));
 	//PREFS->euro_thsep = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_thsep));
 
 	ui_gtk_entry_replace_text(data->ST_euro_symbol, &PREFS->minor_cur.symbol);
-	PREFS->minor_cur.is_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix));
+	PREFS->minor_cur.sym_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix));
 	ui_gtk_entry_replace_text(data->ST_euro_decimalchar, &PREFS->minor_cur.decimal_char);
 	ui_gtk_entry_replace_text(data->ST_euro_groupingchar, &PREFS->minor_cur.grouping_char);
 	PREFS->minor_cur.frac_digits = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_euro_fracdigits));
@@ -1141,9 +1093,11 @@ const gchar *lang;
 
 	/* import */
 	PREFS->dtex_datefmt = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_dtex_datefmt));
+
 	PREFS->dtex_ofxmemo = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_dtex_ofxmemo));
 
 
+
 	//PREFS->chart_legend = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_chartlegend));
 
 }
@@ -1319,7 +1273,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 	
 	row = 1;
-	label = make_label_widget(_("Color Scheme:"));
+	label = make_label_widget(_("Color scheme:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_cycle(label, chart_colors);
@@ -1379,7 +1333,7 @@ gint crow, row;
 
 static GtkWidget *defpref_page_euro (struct defpref_data *data)
 {
-GtkWidget *content_grid, *group_grid, *label, *widget;
+GtkWidget *content_grid, *group_grid, *label, *widget, *expander;
 gint crow, row;
 
 	content_grid = gtk_grid_new();
@@ -1396,102 +1350,111 @@ gint crow, row;
 	label = make_label_group(_("General"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
-/*	label = make_label(_("Default currency"), 0.0, 0.5);
-	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 3, row, row+1);
-
-	row++;
-	label = make_label(_("Code:"), 0, 0.5);
-	//----------------------------------------- l, r, t, b
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, 2, row, row+1);
-	widget = make_label(NULL, 0.0, 0.0);
-	data->LB_default = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, 3, row, row+1);
-
-	row++;
-	widget = gtk_button_new_with_mnemonic (_("_Change"));
-	data->BT_default = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, 3, row, row+1);*/
-
-	row = 1;
+	row=1;
 	widget = gtk_check_button_new_with_mnemonic (_("_Enable"));
 	data->CM_euro_enable = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
 
-	row++;
-	label = make_label(_("Fill from:"), 0, 0.5);
-	//----------------------------------------- l, r, t, b
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_euro_presets(label);
-	data->CY_euro_preset = widget;
-	//gtk_grid_attach (GTK_GRID (group_grid), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+	// group :: Currency
+    group_grid = gtk_grid_new ();
+	data->GRP_currency = group_grid;
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
+	
+	label = make_label_group(_("Currency"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 4, 1);
 
-	row++;
-	label = make_label(_("Country:"), 0, 0.5);
-	//----------------------------------------- l, r, t, b
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_label(NULL, 0.0, 0.0);
+	row=1;
+	widget = make_label(NULL, 0.0, 0.5);
 	data->ST_euro_country = widget;
 	//gtk_grid_attach (GTK_GRID (group_grid), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
 
-	row++;
-	label = make_label(_("Value:"), 0, 0.5);
+	//row++;
+	label = make_label_widget(_("_Preset:"));
 	//----------------------------------------- l, r, t, b
+	gtk_grid_attach (GTK_GRID (group_grid), label, 2, row, 1, 1);
+	widget = make_euro_presets(label);
+	data->CY_euro_preset = widget;
+	gtk_widget_set_margin_left (label, 2*SPACING_LARGE);
+	//gtk_grid_attach (GTK_GRID (group_grid), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 3, row, 1, 1);
+
+	
+	// group :: Exchange rate
+    group_grid = gtk_grid_new ();
+	data->GRP_rate = group_grid;
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
+
+	label = make_label_group(_("Exchange rate"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
+
+	row=1;
+	label = make_label_widget("1 EUR _=");
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_exchange_rate (label);
+	widget = make_exchange_rate(label);
 	data->NB_euro_value = widget;
 	//gtk_grid_attach (GTK_GRID (group_grid), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	// group :: Numbers format
     group_grid = gtk_grid_new ();
+	data->GRP_format = group_grid;
 	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
 	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
 	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
 	
-	label = make_label_group(_("Numbers format"));
+	label = make_label_group(_("Format"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("Symbol:"), 0, 0.5);
+	widget = make_label(NULL, 0, 0.0);
+	data->LB_numbereuro = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+
+	row++;
+	expander = gtk_expander_new_with_mnemonic(_("_Customize"));
+	gtk_grid_attach (GTK_GRID (group_grid), expander, 1, row, 1, 1);
+
+    group_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_container_add (GTK_CONTAINER (expander), group_grid);
+	
+	row = 0;
+	label = make_label_widget(_("_Symbol:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_string_maxlength(label, 3);
 	data->ST_euro_symbol = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("Is prefix"));
+	widget = gtk_check_button_new_with_mnemonic (_("Is pre_fix"));
 	data->CM_euro_isprefix = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("Decimal char:"), 0, 0.5);
+	label = make_label_widget(_("_Decimal char:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_string_maxlength(label, 1);
 	data->ST_euro_decimalchar = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("Grouping char:"), 0, 0.5);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_string_maxlength(label, 1);
-	data->ST_euro_groupingchar = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
-
-	row++;
-	label = make_label(_("_Frac digits:"), 0, 0.5);
+	label = make_label_widget(_("_Frac digits:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_numeric(label, 0.0, 6.0);
 	data->NB_euro_fracdigits = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(NULL, 0, 0.5);
+	label = make_label_widget(_("_Grouping char:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_label(NULL, 0, 0.5);
-	data->LB_numbereuro = widget;
+	widget = make_string_maxlength(label, 1);
+	data->ST_euro_groupingchar = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	return content_grid;
@@ -1500,7 +1463,7 @@ gint crow, row;
 
 static GtkWidget *defpref_page_display (struct defpref_data *data)
 {
-GtkWidget *content_grid, *group_grid, *label, *widget;
+GtkWidget *content_grid, *group_grid, *label, *widget, *expander;
 gint crow, row;
 
 	content_grid = gtk_grid_new();
@@ -1514,11 +1477,25 @@ gint crow, row;
 	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
 	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
 	
-	label = make_label_group(_("Date options"));
+	label = make_label_group(_("Date"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("_Date format:"), 0, 0.5);
+	widget = make_label(NULL, 0, 0.5);
+	data->LB_date = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+
+	row++;
+	expander = gtk_expander_new_with_mnemonic(_("_Customize"));
+	gtk_grid_attach (GTK_GRID (group_grid), expander, 1, row, 1, 1);
+
+    group_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_container_add (GTK_CONTAINER (expander), group_grid);
+
+	row = 1;
+	label = make_label_widget(_("_Format:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_string(label);
@@ -1526,6 +1503,10 @@ gint crow, row;
 	//gtk_grid_attach (GTK_GRID (group_grid), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
+	widget = gtk_image_new_from_icon_name (ICONNAME_INFO, GTK_ICON_SIZE_BUTTON);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 3, row, 1, 1);
+
+	
 	gtk_widget_set_tooltip_text(widget,
 	_("%a locale's abbreviated weekday name.\n"
 "%A locale's full weekday name. \n"
@@ -1543,65 +1524,9 @@ gint crow, row;
 "%Y year with century as a decimal number. \n")
 );
 
-
 	row++;
-	label = make_label(NULL, 0, 0.5);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_label(NULL, 0, 0.5);
-	data->LB_date = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
-
-	// group :: Numbers options
-    group_grid = gtk_grid_new ();
-	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
-	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
-	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
-	
-	label = make_label_group(_("Numbers options"));
-	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
-
-	row = 1;
-	label = make_label(_("Symbol:"), 0, 0.5);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_string_maxlength(label, 3);
-	data->ST_num_symbol = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
-
-	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("Is prefix"));
-	data->CM_num_isprefix = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
-
-	row++;
-	label = make_label(_("Decimal char:"), 0, 0.5);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_string_maxlength(label,1);
-	data->ST_num_decimalchar = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
-
-	row++;
-	label = make_label(_("Grouping char:"), 0, 0.5);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_string_maxlength(label, 1);
-	data->ST_num_groupingchar = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
-
-	row++;
-	label = make_label(_("_Frac digits:"), 0, 0.5);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	#if MYDEBUG
-		widget = make_numeric(label, 0.0, 15.0);
-	#else
-		widget = make_numeric(label, 0.0, 6.0);
-	#endif
-	data->NB_num_fracdigits = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
-
-	row++;
-	label = make_label(NULL, 0, 0.5);
-	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_label(NULL, 0, 0.5);
-	data->LB_numberbase = widget;
+	widget = make_label(NULL, 0.0, 0.5);
+	gtk_label_set_markup (GTK_LABEL(widget), "<small><a href=\"http://man7.org/linux/man-pages/man3/strftime.3.html\">online reference</a></small>");
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	// group :: Measurement units
@@ -1752,9 +1677,13 @@ gint crow, row;
 
 
 	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("Enable rows in alternating colors"));
-	data->CM_ruleshint = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+	//widget = gtk_check_button_new_with_mnemonic (_("Enable rows in alternating colors"));
+	//data->CM_ruleshint = widget;
+	label = make_label_widget(_("_Grid line:"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+	widget = make_cycle(label, CYA_GRID_LINES);
+	data->CY_gridlines = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	// group :: Amount colors
     group_grid = gtk_grid_new ();
@@ -1848,6 +1777,11 @@ gint crow, row;
 	data->CM_append_scheduled = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
 
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("Update currencies online"));
+	data->CM_do_update_currency = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+
 	// group :: Fiscal year
     group_grid = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
@@ -2190,13 +2124,6 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 	g_signal_connect (data.CY_color_scheme, "changed", G_CALLBACK (defpref_color_scheme_changed), NULL);
 
 
-	//base number
-    g_signal_connect (data.ST_num_symbol   , "changed", G_CALLBACK (defpref_numberbase_sample), NULL);
-	g_signal_connect (data.CM_num_isprefix, "toggled", G_CALLBACK (defpref_numberbase_sample), NULL);
-    g_signal_connect (data.ST_num_decimalchar, "changed", G_CALLBACK (defpref_numberbase_sample), NULL);
-    g_signal_connect (data.ST_num_groupingchar, "changed", G_CALLBACK (defpref_numberbase_sample), NULL);
-    g_signal_connect (data.NB_num_fracdigits, "value-changed", G_CALLBACK (defpref_numberbase_sample), NULL);
-
 	//euro number
     g_signal_connect (data.ST_euro_symbol   , "changed", G_CALLBACK (defpref_numbereuro_sample), NULL);
 	g_signal_connect (data.CM_euro_isprefix, "toggled", G_CALLBACK (defpref_numbereuro_sample), NULL);
